#
# spec file for package gcc41
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# icecream 0


# PREFIX_FOR_OPT is the definition for _prefix
# LIBDIR_FOR_OPT is the definition for _libdir

# Run the testsuite if there's a file named RUN_TESTS in the source
%if 0%{!?run_tests:1}
%define run_tests %(test -f %_sourcedir/RUN_TESTS && echo 1 || echo 0)
%endif

# Ada currently fails to build on a few platforms, enable it only
# on those that work
# Note that AdaCore only supports %ix86, x86_64 and ia64
%ifarch %ix86 x86_64 ia64 hppa ppc s390
%define build_ada 1
%else
# alpha ppc64 s390x
%define build_ada 0
%endif

# We don't want to build java on arm
%ifarch mips %arm
%define build_java 0
%define build_libjava 0
%else
%define build_java 1
%define build_libjava 0%{?building_libjava:1}
%endif

%define build_fortran 1
%define build_objcp 0%{!?building_libjava:1}

%if 0%{?build_for_base:1}
%define build_ada 0 
%define build_java 0
%define build_libjava 0
%define build_fortran 0
%define build_objcp 0
%define run_tests 0
%endif

Name:           gcc41
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gettext-devel
BuildRequires:  perl
BuildRequires:  zlib-devel
%if %{suse_version} > 1220
BuildRequires:  makeinfo
%else
BuildRequires:  texinfo
%endif
ExcludeArch:    %arm
%if %{build_ada}
%if %{suse_version} > 1010
%define hostsuffix -4.1
BuildRequires:  gcc41-ada
%else
%define hostsuffix %{nil}
BuildRequires:  gcc-ada
%endif
%endif
%if %{build_libjava}
BuildRequires:  gtk2-devel
BuildRequires:  libart_lgpl-devel
BuildRequires:  unzip
%if %{suse_version} > 1210
BuildRequires:  xorg-x11-devel
%endif
%endif
%if %{build_fortran}
BuildRequires:  mpfr-devel
%endif
%ifarch ia64
BuildRequires:  libunwind-devel
%endif
%if %{run_tests}
BuildRequires:  dejagnu
BuildRequires:  expect
%endif

# Define this as 1 to get gcc packages for business products
%define gcc_for_opt 0

# Disable the use of icecream for this package.  It would generate
# too much parallelism when building state2 and stage3 and the runtime libs
# Just touch RUN_TESTS in the source dir to run the testsuite.
%if %{gcc_for_opt}
%define run_tests 0
%endif

# Define version number of libgcc_s
%ifarch hppa
%define libgcc_s 4
%else
%define libgcc_s 1
%endif
%ifarch ppc
# We support building the nof libraries, but don't want this in the
# regular rpms
%define build_nof 0
%else
%define build_nof 0
%endif

%define separate_bi32 0
%define separate_bi64 0
%ifarch ppc
# Beware, this does _not_ separate libgcj, as for that one multilibing
# is inactive for the time being
%define separate_bi64 1
%endif
%ifarch x86_64 s390x
%define separate_bi32 1
%endif

# Define two macros to trigger -32bit or -64bit package variants
%define separate_biarch 0
%if %{separate_bi32}
%define separate_biarch 1
%define separate_biarch_suffix -32bit
%endif
%if %{separate_bi64}
%define separate_biarch 1
%define separate_biarch_suffix -64bit
%endif

%ifarch x86_64 ia64 s390x alpha ppc64
# 64-bit is primary build target
%define build_primary_64bit 1
%else
%define build_primary_64bit 0
%endif

%define biarch_libjava 0

# COMMON-BEGIN
%define biarch_targets x86_64 s390x powerpc64 powerpc

Url:            http://gcc.gnu.org/
Version:        4.1.2_20070115
Release:        30.1
%define gcc_version %(echo %version | sed 's/_.*//')
%define snapshot_date %(echo %version | sed 's/[34]\.[0-4]\.[0-6]//' | sed 's/_/-/')
%define binsuffix -4.1
%if %{gcc_for_opt}
%define versionspecificlibs 1
%else
%define versionspecificlibs 0
%endif
# COMMON-END

%if 0%{?!building_libjava:1}
Requires:       binutils
Requires:       cpp41 = %{version}-%{release}
Requires:       glibc-devel
Requires:       libgcc_s%{libgcc_s} >= %{version}-%{release}
Obsoletes:      gcc41-mudflap
Requires:       libmudflap0 >= %{version}-%{release}
%endif

# COMMON-BEGIN
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         gcc-%{gcc_version}%{snapshot_date}.tar.bz2
Source1:        change_spec
Source2:        gcc41-rpmlintrc	
Source5:        README.First-for.SuSE.packagers
Source6:        baselibs.conf
Patch1:         bug-reporting.patch
Patch2:         gcc-noalias-warn.diff
Patch5:         boehm-gc-strict-aliasing.patch
Patch7:         acats-timeout.patch
Patch8:         gcc41-makeinfo.patch
Patch9:         gcc41-binutils-version.patch
Patch10:        program-transform-name.diff
Patch12:        gcc4-ppc64-m32-m64-multilib-only.patch
Patch23:        libjava-no-multilib.diff
Patch24:        tls-no-direct.diff
Patch37:        pr20425.patch
Patch38:        large-gcc.diff
Patch43:        generic-cpu-model-1.patch
Patch44:        generic-cpu-model-2.patch
Patch45:        generic-cpu-model-3.patch
Patch47:        partial-flag-regstall.patch
Patch39:        tree_expr_nonzero.patch
Patch40:        vrp.patch
Patch46:        force_fit_type.patch
Patch48:        pr24879.patch
Patch82:        pr13212.patch
Patch93:        nvl161673.patch
Patch95:        pr26399.patch
Patch96:        nov189571.diff
Patch97:        nov189571-2.diff
Patch98:        nvl199137.patch
Patch100:       pr28755.patch
Patch101:       pr30113.patch
Patch102:       ia64-bad-prologue-generation.patch
Patch103:       pr34130.patch
Patch104:       nov480052.diff
Patch105:       pr34641.patch
Patch107:       fix-ada-build.diff
Patch108:       pr20218.patch
Patch109:       pr29558.patch
Patch110:       pr29512.patch
Patch111:       nov495844.diff
Patch112:       pr31499.patch
Patch123:       gcc41-no-unwind-tables.diff
Patch124:       pr28460.patch
Patch125:       gcc-unwind-glibc216.patch
# A set of patches from the RH srpm
Patch51:        gcc41-ia64-stack-protector.patch
Patch55:        gcc41-java-slow_pthread_self.patch
Patch57:        gcc41-ppc32-retaddr.patch
Patch54:        gcc41-ldbl-default.patch
Patch50:        gcc41-ldbl-default-libstdc++.patch
Patch52:        note-gnu-stack.diff
Patch53:        gcc41-strncat-chk.patch
# general improvement patches
Patch60:        pr25626.patch
Patch61:        fortran-matmul.patch
Patch62:        gcc41-fortran-where-opt.patch
Patch63:        emmintr.patch
Patch64:        libstdcxx-bitset.patch
Patch65:        stack-protect-kernel.patch
Patch66:        pr26208.patch
Patch67:        dwarf3-constants.patch
Patch68:        dwarf3-unwind.patch
Patch69:        gcc41-ssse3.patch
Patch70:        pr27880.diff
Patch72:        Wprofile-mismatch.patch
Patch73:        fpreserve-function-arguments4.patch
Patch74:        warn-enum.diff
Patch75:        nov277135.diff
Patch76:        nov376357.diff
Patch77:        nov394409.diff
Patch78:        nov354405.diff
Patch79:        nov494022.diff
Patch80:        nov415378.diff
Patch81:        nov465381.diff
Patch90:        parentheses-mathematical-5.diff
Patch91:        Wuninitialized.patch
# Greyhound (aka AMD Family 10h) support
Patch200:       gcc-amdfam10-suse-1.patch
Patch201:       gcc-amdfam10-suse-2.patch
Patch202:       gcc-amdfam10-suse-3.patch
Patch203:       gcc-amdfam10-suse-4.patch
Patch204:       gcc-amdfam10-suse-5.patch
Patch205:       gcc-amdfam10-suse-6.patch
Patch206:       gcc-amdfam10-suse-7.patch
Patch207:       gcc-amdfam10-suse-8.patch
Patch208:       gcc-amdfam10-suse-9.patch
Patch209:       gcc-amdfam10-suse-10.patch
Patch210:       gcc-amdfam10-suse-11.patch
Patch211:       gcc-amdfam10-suse-12.patch
Patch212:       gcc-amdfam10-suse-20.patch
Patch213:       gcc-amdfam10-alignloop.diff
Patch214:       barcelona.patch
Patch215:       sse5-suse.patch01
# POWER6 support
Patch300:       gcc-4.1.0-power6.diff
Patch301:       nov341254-pic.diff
Patch302:       nov341254-altivec.diff

%if "%{gcc_target_arch}" == "avr"
# Joerg Wunsch places his cross-avr-gcc-patches there:
# http://www.freebsd.org/cgi/cvsweb.cgi/ports/devel/avr-gcc/files
# grab what has not yet made it into upstream
Patch1000:      cross-avr-patch-0b-constants.patch
Patch1001:      cross-avr-patch-attribute_alias.patch
Patch1002:      cross-avr-patch-bug25672.patch
Patch1003:      cross-avr-patch-dwarf.patch
Patch1004:      cross-avr-patch-newdevices.patch
Patch1005:      cross-avr-patch-zz-atmega256x.patch
%endif

# LIBJAVA-DELETE-BEGIN
Summary:        The GNU C Compiler and Support Files
License:        GPL-2.0+
Group:          Development/Languages/C and C++

%description
Language frontends other than C are split to different sub-packages,
namely gcc-ada, gcc-c++, gcc-fortran, gcc-java and gcc-objc.


# COMMON-END
%package -n gcc41-32bit
Summary:        The GNU C Compiler 32bit support
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Requires:       gcc41 = %{version}-%{release}
Requires:       libgcc_s%{libgcc_s}-32bit >= %{version}-%{release}
Obsoletes:      gcc41-mudflap-32bit
Requires:       libmudflap0-32bit >= %{version}-%{release}

%description -n gcc41-32bit 
This package contains 32bit support for the GNU Compiler Collection.

%package -n gcc41-64bit
Summary:        The GNU C Compiler 64bit support
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Requires:       gcc41 = %{version}-%{release}
Requires:       libgcc_s%{libgcc_s}-64bit >= %{version}-%{release}
Obsoletes:      gcc41-mudflap-64bit
Requires:       glibc-devel-64bit
Requires:       libmudflap0-64bit >= %{version}-%{release}

%description -n gcc41-64bit
This package contains 64bit support for the GNU Compiler Collection.


%package locale
Summary:        gcc-locale
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Requires:       gcc41 = %{version}-%{release}

%description locale


%package c++
Summary:        The GNU C++ Compiler
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Requires:       gcc41 = %{version}-%{release}
Requires:       libstdc++41-devel = %{version}-%{release}

%description c++
This package contains the GNU compiler for C++.

# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libstdc++41-devel
Summary:        Include Files and Libraries mandatory for Development
License:        GPL-2.0+
Group:          System/Libraries
Requires:       glibc-devel
Requires:       libstdc++6 >= %{version}-%{release}
%ifarch ia64
Requires:       libunwind-devel
%endif

%description -n libstdc++41-devel
This package contains all the headers and libraries of the standard C++
library. It is needed for compiling C++ code.
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libstdc++41-devel-32bit
Summary:        Include Files and Libraries mandatory for Development
License:        GPL-2.0+
Group:          System/Libraries
Requires:       libstdc++6-32bit >= %{version}-%{release}
%ifarch ia64
Requires:       libunwind-devel
%endif

%description -n libstdc++41-devel-32bit
This package contains all the headers and libraries of the standard C++
library. It is needed for compiling C++ code.
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libstdc++41-devel-64bit
Summary:        Include Files and Libraries mandatory for Development
License:        GPL-2.0+
Group:          System/Libraries
Requires:       glibc-devel-64bit
Requires:       libstdc++6-64bit >= %{version}-%{release}
%ifarch ia64
Requires:       libunwind-devel
%endif

%description -n libstdc++41-devel-64bit
This package contains all the headers and libraries of the standard C++
library. It is needed for compiling C++ code.
# PACKAGE-END

%package -n libstdc++41-doc
Summary:        Documentation for the GNU C++ standard library
License:        GPL-2.0+
Group:          Development/Languages/C and C++

%description -n libstdc++41-doc
Documentation for the GNU C++ standard library

# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libgcc41
Summary:        C compiler runtime library
License:        GPL-2.0+
Group:          System/Base
Provides:       libgcc%{libgcc_s} = %{version}-%{release}
Provides:       libgcc_s%{libgcc_s} = %{version}-%{release}
Conflicts:      libgcc%{libgcc_s} < %{version}-%{release}
%if "41" != ""
Provides:       libgcc = %{version}-%{release}
Obsoletes:      libgcc < %{version}-%{release}
%endif

%description -n libgcc41
Libgcc is needed for dynamically linked C programs.

%post -n libgcc41
/sbin/ldconfig

%postun -n libgcc41
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libgcc41-32bit
Summary:        C compiler runtime library
License:        GPL-2.0+
Group:          System/Base
Provides:       libgcc%{libgcc_s}-32bit = %{version}-%{release}
Provides:       libgcc_s%{libgcc_s}-32bit = %{version}-%{release}
Conflicts:      libgcc%{libgcc_s}-32bit < %{version}-%{release}
%if "41" != ""
Provides:       libgcc-32bit = %{version}-%{release}
Obsoletes:      libgcc-32bit < %{version}-%{release}
%endif

%description -n libgcc41-32bit
Libgcc is needed for dynamically linked C programs.

%post -n libgcc41-32bit
/sbin/ldconfig

%postun -n libgcc41-32bit
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libgcc41-64bit
Summary:        C compiler runtime library
License:        GPL-2.0+
Group:          System/Base
Provides:       libgcc%{libgcc_s}-64bit = %{version}-%{release}
Provides:       libgcc_s%{libgcc_s}-64bit = %{version}-%{release}
Conflicts:      libgcc%{libgcc_s}-64bit < %{version}-%{release}
%if "41" != ""
Provides:       libgcc-64bit = %{version}-%{release}
Obsoletes:      libgcc-64bit < %{version}-%{release}
%endif

%description -n libgcc41-64bit
Libgcc is needed for dynamically linked C programs.

%post -n libgcc41-64bit
/sbin/ldconfig

%postun -n libgcc41-64bit
/sbin/ldconfig
# PACKAGE-END

# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libstdc++41
Summary:        The standard C++ shared library
License:        GPL-2.0+
Group:          System/Libraries
Provides:       libstdc++6 = %{version}-%{release}
Conflicts:      libstdc++6 < %{version}-%{release}
%if "41" != ""
Provides:       libstdc++ = %{version}-%{release}
Obsoletes:      libstdc++ < %{version}-%{release}
%endif

%description -n libstdc++41
The standard C++ library, needed for dynamically linked C++ programs.

Authors:
--------
    Paolo Carlini <pcarlini@suse.de>
    Gabriel Dos Reis <gdr@integrable-solutions.net>
    Ulrich Drepper <drepper@redhat.com>
    Phil Edwards <pme@gcc.gnu.org>
    Benjamin Kosnik <bkoz@redhat.com>
    Loren J. Rittle <ljrittle@acm.org>
    et.al.

%post -n libstdc++41
/sbin/ldconfig

%postun -n libstdc++41
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libstdc++41-32bit
Summary:        The standard C++ shared library
License:        GPL-2.0+
Group:          System/Libraries
Provides:       libstdc++6-32bit = %{version}-%{release}
Conflicts:      libstdc++6-32bit < %{version}-%{release}
%if "41" != ""
Provides:       libstdc++-32bit = %{version}-%{release}
Obsoletes:      libstdc++-32bit < %{version}-%{release}
%endif

%description -n libstdc++41-32bit
The standard C++ library, needed for dynamically linked C++ programs.

Authors:
--------
    Paolo Carlini <pcarlini@suse.de>
    Gabriel Dos Reis <gdr@integrable-solutions.net>
    Ulrich Drepper <drepper@redhat.com>
    Phil Edwards <pme@gcc.gnu.org>
    Benjamin Kosnik <bkoz@redhat.com>
    Loren J. Rittle <ljrittle@acm.org>
    et.al.

%post -n libstdc++41-32bit
/sbin/ldconfig

%postun -n libstdc++41-32bit
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libstdc++41-64bit
Summary:        The standard C++ shared library
License:        GPL-2.0+
Group:          System/Libraries
Provides:       libstdc++6-64bit = %{version}-%{release}
Conflicts:      libstdc++6-64bit < %{version}-%{release}
%if "41" != ""
Provides:       libstdc++-64bit = %{version}-%{release}
Obsoletes:      libstdc++-64bit < %{version}-%{release}
%endif

%description -n libstdc++41-64bit
The standard C++ library, needed for dynamically linked C++ programs.

Authors:
--------
    Paolo Carlini <pcarlini@suse.de>
    Gabriel Dos Reis <gdr@integrable-solutions.net>
    Ulrich Drepper <drepper@redhat.com>
    Phil Edwards <pme@gcc.gnu.org>
    Benjamin Kosnik <bkoz@redhat.com>
    Loren J. Rittle <ljrittle@acm.org>
    et.al.

%post -n libstdc++41-64bit
/sbin/ldconfig

%postun -n libstdc++41-64bit
/sbin/ldconfig
# PACKAGE-END

%package info
Summary:        GNU Info-Pages for GCC
License:        GPL-2.0+
Group:          Development/Languages/C and C++
PreReq:         %{install_info_prereq}
%if %{gcc_for_opt}
Conflicts:      gcc-info
%endif

%description info
GNU info-pages for GCC.


# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package objc
Summary:        GNU Objective C Compiler
License:        GPL-2.0+
Group:          Development/Languages/Other
Requires:       gcc41 = %{version}-%{release}
Requires:       libobjc >= %{version}-%{release}

%description objc
This package contains the GNU Objective C compiler. Objective C is an
object oriented language, created by Next Inc. and used in their
Nextstep OS. The source code is available in the gcc package.
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package objc-32bit
Summary:        GNU Objective C Compiler
License:        GPL-2.0+
Group:          Development/Languages/Other
Requires:       gcc41-32bit = %{version}-%{release}
Requires:       libobjc-32bit >= %{version}-%{release}

%description objc-32bit
This package contains the GNU Objective C compiler. Objective C is an
object oriented language, created by Next Inc. and used in their
Nextstep OS. The source code is available in the gcc package.
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package objc-64bit
Summary:        GNU Objective C Compiler
License:        GPL-2.0+
Group:          Development/Languages/Other
Requires:       gcc41-64bit = %{version}-%{release}
Requires:       libobjc-64bit >= %{version}-%{release}

%description objc-64bit
This package contains the GNU Objective C compiler. Objective C is an
object oriented language, created by Next Inc. and used in their
Nextstep OS. The source code is available in the gcc package.
# PACKAGE-END

# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libobjc41
Summary:        Library for the GNU Objective C Compiler
License:        GPL-2.0+
Group:          Development/Libraries/Other
%if "41" != ""
Provides:       libobjc = %{version}-%{release}
Obsoletes:      libobjc < %{version}-%{release}
%endif
# make SLE10 ppc -> SLE11 ppc64 update happy
%if "" == ""
%ifarch ppc64
Obsoletes:      libobjc-64bit
%endif
%endif

%description -n libobjc41
The library for the GNU Objective C compiler.

%post -n libobjc41
/sbin/ldconfig

%postun -n libobjc41
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libobjc41-32bit
Summary:        Library for the GNU Objective C Compiler
License:        GPL-2.0+
Group:          Development/Libraries/Other
%if "41" != ""
Provides:       libobjc-32bit = %{version}-%{release}
Obsoletes:      libobjc-32bit < %{version}-%{release}
%endif
# make SLE10 ppc -> SLE11 ppc64 update happy
%if "-32bit" == ""
%ifarch ppc64
Obsoletes:      libobjc-64bit
%endif
%endif

%description -n libobjc41-32bit
The library for the GNU Objective C compiler.

%post -n libobjc41-32bit
/sbin/ldconfig

%postun -n libobjc41-32bit
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libobjc41-64bit
Summary:        Library for the GNU Objective C Compiler
License:        GPL-2.0+
Group:          Development/Libraries/Other
%if "41" != ""
Provides:       libobjc-64bit = %{version}-%{release}
Obsoletes:      libobjc-64bit < %{version}-%{release}
%endif
# make SLE10 ppc -> SLE11 ppc64 update happy
%if "-64bit" == ""
%ifarch ppc64
Obsoletes:      libobjc-64bit
%endif
%endif

%description -n libobjc41-64bit
The library for the GNU Objective C compiler.

%post -n libobjc41-64bit
/sbin/ldconfig

%postun -n libobjc41-64bit
/sbin/ldconfig
# PACKAGE-END

%package obj-c++
Summary:        GNU Objective C++ Compiler
License:        GPL-2.0+
Group:          Development/Languages/Other
Requires:       gcc41-c++ = %{version}-%{release}
Requires:       gcc41-objc = %{version}-%{release}

%description obj-c++
This package contains the GNU Objective C++ compiler. Objective C++ is an
object oriented language, created by Next Inc. and used in their
Nextstep OS. The source code is available in the gcc package.


%package -n cpp41
Summary:        The GCC Preprocessor
License:        GPL-2.0+
Group:          Development/Languages/C and C++

%description -n cpp41
This Package contains just the preprocessor that is used by the X11
packages.


%package ada
Requires:       gcc41 = %{version}-%{release}
Requires:       libada41 = %{version}-%{release}
Summary:        GNU Ada95 Compiler Based on GCC (GNAT)
License:        GPL-2.0+
Group:          Development/Languages/Other
Provides:       gnat
Obsoletes:      gnat

%description ada
This package contains an Ada95 compiler and associated development
tools based on the GNU GCC technology. Ada95 is the object oriented
successor of the Ada83 language. To build this package from source you
must have installed a binary version to bootstrap the compiler.


%package -n libada41
Summary:        GNU Ada Runtime Libraries
License:        GPL-2.0+
Group:          System/Libraries
Provides:       libada
Obsoletes:      libada
Provides:       gnat-runtime
Obsoletes:      gnat-runtime

%description -n libada41
This package contains the shared libraries required to run programs
compiled with the GNU Ada compiler (GNAT) if they are compiled to use
shared libraries. It also contains the shared libraries for the
Implementation of the Ada Semantic Interface Specification (ASIS), the
implementation of Distributed Systems Programming (GLADE) and the Posix
1003.5 Binding (Florist).

%post -n libada41
/sbin/ldconfig

%postun -n libada41
/sbin/ldconfig

# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package fortran
Summary:        The GNU Fortran Compiler and Support Files
License:        GPL-2.0+
Group:          Development/Languages/Fortran
Requires:       gcc41 = %{version}-%{release}
Requires:       libgfortran >= %{version}-%{release}

%description fortran
This is the Fortran compiler of the GNU Compiler Collection (GCC).
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package fortran-32bit
Summary:        The GNU Fortran Compiler and Support Files
License:        GPL-2.0+
Group:          Development/Languages/Fortran
Requires:       gcc41-32bit = %{version}-%{release}
Requires:       libgfortran-32bit >= %{version}-%{release}

%description fortran-32bit
This is the Fortran compiler of the GNU Compiler Collection (GCC).
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package fortran-64bit
Summary:        The GNU Fortran Compiler and Support Files
License:        GPL-2.0+
Group:          Development/Languages/Fortran
Requires:       gcc41-64bit = %{version}-%{release}
Requires:       libgfortran-64bit >= %{version}-%{release}

%description fortran-64bit
This is the Fortran compiler of the GNU Compiler Collection (GCC).
# PACKAGE-END

# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libgfortran41
Summary:        The GNU Fortran Compiler Runtime Library
License:        GPL-2.0+
Group:          Development/Languages/Fortran
%if "41" != ""
Provides:       libgfortran = %{version}-%{release}
Obsoletes:      libgfortran < %{version}-%{release}
%endif
# make SLE10 ppc -> SLE11 ppc64 update happy
%if "" == ""
%ifarch ppc64
Obsoletes:      libgfortran-64bit
%endif
%endif

%description -n libgfortran41
The runtime library needed to run programs compiled with the Fortran compiler
of the GNU Compiler Collection (GCC).

%post -n libgfortran41
/sbin/ldconfig

%postun -n libgfortran41
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libgfortran41-32bit
Summary:        The GNU Fortran Compiler Runtime Library
License:        GPL-2.0+
Group:          Development/Languages/Fortran
%if "41" != ""
Provides:       libgfortran-32bit = %{version}-%{release}
Obsoletes:      libgfortran-32bit < %{version}-%{release}
%endif
# make SLE10 ppc -> SLE11 ppc64 update happy
%if "-32bit" == ""
%ifarch ppc64
Obsoletes:      libgfortran-64bit
%endif
%endif

%description -n libgfortran41-32bit
The runtime library needed to run programs compiled with the Fortran compiler
of the GNU Compiler Collection (GCC).

%post -n libgfortran41-32bit
/sbin/ldconfig

%postun -n libgfortran41-32bit
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libgfortran41-64bit
Summary:        The GNU Fortran Compiler Runtime Library
License:        GPL-2.0+
Group:          Development/Languages/Fortran
%if "41" != ""
Provides:       libgfortran-64bit = %{version}-%{release}
Obsoletes:      libgfortran-64bit < %{version}-%{release}
%endif
# make SLE10 ppc -> SLE11 ppc64 update happy
%if "-64bit" == ""
%ifarch ppc64
Obsoletes:      libgfortran-64bit
%endif
%endif

%description -n libgfortran41-64bit
The runtime library needed to run programs compiled with the Fortran compiler
of the GNU Compiler Collection (GCC).

%post -n libgfortran41-64bit
/sbin/ldconfig

%postun -n libgfortran41-64bit
/sbin/ldconfig
# PACKAGE-END

# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libmudflap41
Summary:        The Mudflap Extension Runtime Library
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Provides:       libmudflap0 = %{version}-%{release}
Conflicts:      libmudflap0 < %{version}-%{release}
Provides:       libmudflapth0 = %{version}-%{release}
Conflicts:      libmudflapth0 < %{version}-%{release}
%if "41" != ""
Provides:       libmudflap = %{version}-%{release}
%endif
# make SLE10 ppc -> SLE11 ppc64 update happy
%if "" == ""
%ifarch ppc64
Obsoletes:      libmudflap-64bit
%endif
%endif

%description -n libmudflap41
This is the Mudflap Extension Runtime Library.

%post -n libmudflap41
/sbin/ldconfig

%postun -n libmudflap41
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libmudflap41-32bit
Summary:        The Mudflap Extension Runtime Library
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Provides:       libmudflap0-32bit = %{version}-%{release}
Conflicts:      libmudflap0-32bit < %{version}-%{release}
Provides:       libmudflapth0-32bit = %{version}-%{release}
Conflicts:      libmudflapth0-32bit < %{version}-%{release}
%if "41" != ""
Provides:       libmudflap-32bit = %{version}-%{release}
%endif
# make SLE10 ppc -> SLE11 ppc64 update happy
%if "-32bit" == ""
%ifarch ppc64
Obsoletes:      libmudflap-64bit
%endif
%endif

%description -n libmudflap41-32bit
This is the Mudflap Extension Runtime Library.

%post -n libmudflap41-32bit
/sbin/ldconfig

%postun -n libmudflap41-32bit
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libmudflap41-64bit
Summary:        The Mudflap Extension Runtime Library
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Provides:       libmudflap0-64bit = %{version}-%{release}
Conflicts:      libmudflap0-64bit < %{version}-%{release}
Provides:       libmudflapth0-64bit = %{version}-%{release}
Conflicts:      libmudflapth0-64bit < %{version}-%{release}
%if "41" != ""
Provides:       libmudflap-64bit = %{version}-%{release}
%endif
# make SLE10 ppc -> SLE11 ppc64 update happy
%if "-64bit" == ""
%ifarch ppc64
Obsoletes:      libmudflap-64bit
%endif
%endif

%description -n libmudflap41-64bit
This is the Mudflap Extension Runtime Library.

%post -n libmudflap41-64bit
/sbin/ldconfig

%postun -n libmudflap41-64bit
/sbin/ldconfig
# PACKAGE-END

%package java
Summary:        The GNU Java Compiler
License:        GPL-2.0+
Group:          Development/Languages/Java
Requires:       gcc41 = %{version}-%{release}
Requires:       libgcj41-devel = %{version}

%description java
The Java compiler from the GCC-tools-suite.


%package -n libgcj41
# LIBJAVA-DELETE-END
Summary:        Java Runtime Library for gcc
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Libraries
%if "41" != ""
Provides:       libgcj = %{version}-%{release}
Obsoletes:      libgcj < %{version}-%{release}
%endif
# make SLE10 ppc -> SLE11 ppc64 update happy
%ifarch ppc64
Obsoletes:      libgcj-64bit
%endif

%description -n libgcj41
This library is needed if you want to use the GNU Java compiler, gcj.
Source code for this package is in gcc.

%post -n libgcj41
/sbin/ldconfig

%postun -n libgcj41
/sbin/ldconfig

%package -n libgcj41-devel
Summary:        Include Files and Libraries mandatory for Development.
License:        GPL-2.0+
Group:          Development/Libraries/Java
Requires:       glibc-devel
Requires:       gtk2-devel
Requires:       libart_lgpl-devel
Requires:       libgcj >= %{version}-%{release}
Requires:       libstdc++41-devel = %{version}
Requires:       zlib-devel
%ifarch ia64
Requires:       libunwind-devel
%endif

%description -n libgcj41-devel
This package contains all necessary include files and libraries needed
to develop applications that require these.


%package -n gcc41-gij
Summary:        Java Bytecode Interpreter for gcc
License:        GPL-2.0+
Group:          Development/Libraries/Java
Requires:       libgcj >= %{version}-%{release}

%description -n gcc41-gij
This package contains the java bytecode interpreter gij and related tools.


# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libffi41
Summary:        Foreign Function Interface library
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Provides:       g-wrap:/usr/lib/libffi.so.4

%description -n libffi41
A foreign function interface is the popular name for the interface that allows code written in one language to call code written in another language.

%post -n libffi41
/sbin/ldconfig

%postun -n libffi41
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libffi41-32bit
Summary:        Foreign Function Interface library
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Provides:       g-wrap:/usr/lib/libffi.so.4

%description -n libffi41-32bit
A foreign function interface is the popular name for the interface that allows code written in one language to call code written in another language.

%post -n libffi41-32bit
/sbin/ldconfig

%postun -n libffi41-32bit
/sbin/ldconfig
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libffi41-64bit
Summary:        Foreign Function Interface library
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Provides:       g-wrap:/usr/lib/libffi.so.4

%description -n libffi41-64bit
A foreign function interface is the popular name for the interface that allows code written in one language to call code written in another language.

%post -n libffi41-64bit
/sbin/ldconfig

%postun -n libffi41-64bit
/sbin/ldconfig
# PACKAGE-END

# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libffi41-devel
Summary:        Foreign Function Interface library development files
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Requires:       libffi41 >= %{version}-%{release}

%description -n libffi41-devel
A foreign function interface is the popular name for the interface that allows code written in one language to call code written in another language.
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libffi41-devel-32bit
Summary:        Foreign Function Interface library development files
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Requires:       libffi41-32bit >= %{version}-%{release}

%description -n libffi41-devel-32bit
A foreign function interface is the popular name for the interface that allows code written in one language to call code written in another language.
# PACKAGE-END
# PACKAGE-BEGIN
# PACKAGE-BEGIN
%package -n libffi41-devel-64bit
Summary:        Foreign Function Interface library development files
License:        GPL-2.0+
Group:          Development/Languages/C and C++
Requires:       libffi41-64bit >= %{version}-%{release}

%description -n libffi41-devel-64bit
A foreign function interface is the popular name for the interface that allows code written in one language to call code written in another language.
# PACKAGE-END

%package -n gcc41-testresults
Summary:        Testsuite results
License:        GPL-2.0+
Group:          Development/Languages/C and C++

%description -n gcc41-testresults
Results from running the gcc and target library testsuites.


# COMMON-BEGIN

# Define the canonical target and host architecture
#   %gcc_target_arch  is supposed to be the full target triple
#   %TARGET_ARCH      is the canonicalized CPU part
#   %CONFIGURE_TARGET is the target triple used for --target=
%if 0%{?gcc_target_arch:1}
%define CONFIGURE_TARGET %{gcc_target_arch}
%define TARGET_ARCH %(echo %{gcc_target_arch} | cut -d - -f 1 | sed -e "s/i.86/i586/;s/ppc/powerpc/")
%if 0%{?gcc_icecream:1} && %{TARGET_ARCH} == "powerpc"
%define CONFIGURE_TARGET powerpc64-linux
%endif
%else
%define TARGET_ARCH %(echo %{_target_cpu} | sed -e "s/i.86/i586/;s/ppc/powerpc/")
%endif
%define HOST_ARCH %(echo %{_host_cpu} | sed -e "s/i.86/i586/;s/ppc/powerpc/")

%define biarch %(case " %{biarch_targets} " in (*" %{TARGET_ARCH} "*) echo 1;; (*) echo 0;; esac)

%ifarch ppc
%define GCCDIST powerpc64-suse-linux
%else
%define GCCDIST %{HOST_ARCH}-suse-linux
%endif

%define libsubdir %{_libdir}/gcc/%{GCCDIST}/%{gcc_version}
%define gxxinclude %{_prefix}/include/c++/%{gcc_version}

# COMMON-END

# Versionspecific directories
%define versmainlibdir %{libsubdir}
%define versmainlibdirbi32 %{libsubdir}/32
%define versmainlibdirbi64 %{libsubdir}/64
%ifarch ppc
%define versnoflibdir %{libsubdir}/nof
%define versmainlibdirbi32 %{libsubdir}
%define versmainlibdirbi64 %{libsubdir}/64
%endif
%ifarch ppc64
%define versnoflibdir %{libsubdir}/32/nof
%endif

# If we use versionspecific libs, they end in libsubdir
%if %{versionspecificlibs}
%define mainlibdir %{libsubdir}
%define mainlibdirbi32 %{libsubdir}/32
%define mainlibdirbi64 %{libsubdir}/64
%ifarch ppc
%define noflibdir %{libsubdir}/nof
%define mainlibdirbi32 %{libsubdir}
%define mainlibdirbi64 %{libsubdir}/64
%endif
%ifarch ppc64
%define noflibdir %{libsubdir}/32/nof
%endif
%else
%define mainlibdir %{_libdir}
%define mainlibdirbi32 %{_prefix}/lib
%define mainlibdirbi64 %{_prefix}/lib64
%define noflibdir %{_prefix}/lib/nof
%endif

# Now define a few macros that make it easy to package libs and
# related files just to the right package, without caring for the
# exact path the files are in.
#   %mainlib  package X from all dirs that belong to the main package
#   %biarchlib   package X from all dirs that belong to the -32/64bit package
# by default, nof libs go where the 32bit libs go.
%if %{build_nof}
%define mainlib() %{mainlibdir}/%1\
%{noflibdir}/%1\
%{nil}
%else
%define mainlib() %{mainlibdir}/%1\
%{nil}
%endif
%define biarchlib() %{nil}
%if %{biarch}
%if %{build_primary_64bit}
%if !%{separate_bi32}
%if %{build_nof}
%define mainlib() %{mainlibdir}/%1\
%{mainlibdirbi32}/%1\
%{noflibdir}/%1\
%{nil}
%else
%define mainlib() %{mainlibdir}/%1\
%{mainlibdirbi32}/%1\
%{nil}
%endif
%else
%if %{build_nof}
%define biarchlib() %{mainlibdirbi32}/%1\
%{noflibdir}/%1\
%{nil}
%define mainlib() %{mainlibdir}/%1\
%{nil}
%else
%define biarchlib() %{mainlibdirbi32}/%1\
%{nil}
%endif
%endif
%else
%if !%{separate_bi64}
%if %{build_nof}
%define mainlib() %{mainlibdir}/%1\
%{mainlibdirbi64}/%1\
%{noflibdir}/%1\
%{nil}
%else
%define mainlib() %{mainlibdir}/%1\
%{mainlibdirbi64}/%1\
%{nil}
%endif
%else
%define biarchlib() %{mainlibdirbi64}/%1\
%{nil}
%endif
%endif
%endif

%if %{build_nof}
%define versmainlib() %{versmainlibdir}/%1\
%{versnoflibdir}/%1\
%{nil}
%else
%define versmainlib() %{versmainlibdir}/%1\
%{nil}
%endif
%define versbiarchlib() %{nil}
%if %{biarch}
%if %{build_primary_64bit}
%if !%{separate_bi32}
%if %{build_nof}
%define versmainlib() %{versmainlibdir}/%1\
%{versmainlibdirbi32}/%1\
%{versnoflibdir}/%1\
%{nil}
%else
%define versmainlib() %{versmainlibdir}/%1\
%{versmainlibdirbi32}/%1\
%{nil}
%endif
%else
%if %{build_nof}
%define versbiarchlib() %{versmainlibdirbi32}/%1\
%{versnoflibdir}/%1\
%{nil}
%define versmainlib() %{versmainlibdir}/%1\
%{nil}
%else
%define versbiarchlib() %{versmainlibdirbi32}/%1\
%{nil}
%endif
%endif
%else
%if !%{separate_bi64}
%if %{build_nof}
%define versmainlib() %{versmainlibdir}/%1\
%{versmainlibdirbi64}/%1\
%{versnoflibdir}/%1\
%{nil}
%else
%define versmainlib() %{versmainlibdir}/%1\
%{versmainlibdirbi64}/%1\
%{nil}
%endif
%else
%define versbiarchlib() %{versmainlibdirbi64}/%1\
%{nil}
%endif
%endif
%endif

# COMMON-BEGIN

%prep
%setup -q -n gcc-%{gcc_version}%{snapshot_date}
%patch1
%patch2
%patch5
%patch7
%patch8
%patch9
%patch10
%if !%{build_nof}
%patch12
%endif
%patch23
%patch24
%patch37
%patch38
%patch43
%patch44
%patch45
%patch47
%patch39
%patch40
%patch46
%patch48
%patch82
%patch93
%patch95
%patch96
%patch97
%patch98 -p1
%patch100
%patch101
%patch102 -p1
%patch103
%patch104
%patch105
%patch107
%patch108
%patch109
%patch110
%patch111
%patch112
%patch123
%patch124
%patch125 -p1
%patch51
%patch55
%patch57
%patch54
%patch50
%patch52
%patch53
cd libstdc++-v3
%patch60
%patch64
cd ..
%patch61
%patch62 -p1
%patch63
%patch65
%patch66
%patch67
%patch68
%patch69
%patch70
%patch72
%patch73
%patch74
%patch75
%patch76
%patch77
%patch78
%patch79
%patch80
%patch81
%patch90
%patch91
%patch200
%patch201
%patch202
%patch203
%patch204
%patch205
%patch206
%patch207
%patch208
%patch209
%patch210
%patch211
%patch212
%patch213 -p1
%patch214
%patch215
%patch300
%patch301 -p1
%patch302 -p1

%if "%{gcc_target_arch}" == "avr"
%patch1000
%patch1001
%patch1002
%patch1003
%patch1004
%patch1005
%endif

%build
# Avoid conflict with commercial libjawt.so
sed -i -e 's/libjawt/libgcjawt/g' libjava/Makefile.{am,in}

# Avoid rebuilding of generated files
contrib/gcc_update --touch

rm -rf obj-%{GCCDIST}
mkdir obj-%{GCCDIST}
cd obj-%{GCCDIST}
RPM_OPT_FLAGS="$RPM_OPT_FLAGS -U_FORTIFY_SOURCE"
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-fno-rtti//g' -e 's/-fno-exceptions//g' -e 's/-Wmissing-format-attribute//g' -e 's/-fstack-protector[^ ]*//g' -e 's/-ffortify=.//g' -e 's/-grecord-gcc-switches//g'`
%ifarch %ix86
# -mcpu is superceded by -mtune but -mtune is not supported by
# our bootstrap compiler.  -mcpu gives a warning that stops
# the build process, so remove it for now.
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-mcpu=i.86//g'`
%endif
%ifarch s390 s390x
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-fsigned-char//g'`
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-O1/-O2/g'`
%endif
%if 0%{?gcc_target_arch:1} && 0%{!?gcc_icecream:1}
# Kill all -march/tune/cpu because that screws building the target libs
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-m\(arch\|tune\|cpu\)=[^ ]*//g'`
%endif
# Replace 2 spaces by one finally
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/  / /g'`

languages=c,c++,objc
%if %{build_fortran}
languages=$languages,fortran
%endif
%if %{build_objcp}
languages=$languages,obj-c++
%endif
%if %{build_java}
languages=$languages,java
%endif
%if %{build_ada}
languages=$languages,ada
%endif
# override for cross targets until we have build_objc
%if 0%{?gcc_target_arch:1}
languages=c,c++
%endif

J=%{?jobs:%jobs}
if test -z "$J"; then
  J=$(getconf _NPROCESSORS_CONF)
  JL=$(($J * 2))
else
  test 1 -gt "$J" && J=1
  JL=$(($(getconf _NPROCESSORS_CONF)*2))
fi
if test "$J" == "0"; then
  J=1
fi
if test "$JL" == "0"; then
  JL=1
fi
PARALLEL="-j$J -l$JL"

# we don't want some miscompiles in the testsuite, or some fault in
# the compiler to kill the machine.  Hence we limit the amount of memory
# by the physical RAM plus half of swap
#MEM=$(free -m | awk '/^Mem:/ {print $2}')
#SWAP=$(free -m | awk '/^Swap:/ {print $2}')
#ulimit -v $(((MEM + SWAP/2)*1024))

# In general we want to ship release checking enabled compilers
# and run BETA with checking enabled.
#ENABLE_CHECKING=--enable-checking
ENABLE_CHECKING="--enable-checking=release"

%if "%{name}" != "gcc41"
export PATH=/opt/cross/bin:$PATH
%endif

# Work around tail/head -1 changes
export _POSIX2_VERSION=199209

# configure tries to parse include/features.h to detect
# if glibc supports SSP.  When cross compiling we would need
# to install a cross glibc, which we don't, or make the whole
# thing point to the native glibc, which is in /, hence the
# --with-sysroot=/

%if %{build_ada}
# Using the host gnatmake like
#   CC="gcc%{hostsuffix}" GNATBIND="gnatbind%{hostsuffix}"
#   GNATMAKE="gnatmake%{hostsuffix}"
# doesn't work due to PR33857, so an un-suffixed gnatmake has to be
# available
mkdir -p host-tools/bin
cp -a /usr/bin/gnatmake%{hostsuffix} host-tools/bin/gnatmake
cp -a /usr/bin/gnatlink%{hostsuffix} host-tools/bin/gnatlink
cp -a /usr/bin/gnatbind%{hostsuffix} host-tools/bin/gnatbind
cp -a /usr/bin/gcc%{hostsuffix} host-tools/bin/gcc
ln -sf /usr/%{_lib} host-tools/%{_lib}
export PATH="`pwd`/host-tools/bin:$PATH"
%endif
CFLAGS="$RPM_OPT_FLAGS" CXXFLAGS="$RPM_OPT_FLAGS" XCFLAGS="$RPM_OPT_FLAGS" \
TCFLAGS="$RPM_OPT_FLAGS" GCJFLAGS="$RPM_OPT_FLAGS" \
../configure \
%if 0%{?gcc_target_arch:1} && 0%{!?gcc_icecream:1}
%else
	--enable-threads=posix \
%endif
	--prefix=%{_prefix} --with-local-prefix=/usr/local \
	--infodir=%{_infodir} --mandir=%{_mandir} \
	--libdir=%{_libdir} --libexecdir=%{_libdir} \
	--enable-languages=$languages $ENABLE_CHECKING \
	--with-gxx-include-dir=/usr/include/c++/%{gcc_version} \
	--enable-ssp --disable-libssp \
%if !%{build_libjava}
        --disable-libgcj \
%else
        --enable-java-awt=gtk --enable-gtk-cairo \
%if !%{biarch_libjava}
        --disable-libjava-multilib \
%endif
%endif
	--with-slibdir=/%{_lib} --with-system-zlib \
	--enable-shared --enable-__cxa_atexit \
	--enable-libstdcxx-allocator=new \
%if 0%{?gcc_target_arch:1}
%if 0%{?gcc_icecream:1}
	--with-as=/opt/cross/%{TARGET_ARCH}-linux/bin/as \
	--with-ld=/opt/cross/%{TARGET_ARCH}-linux/bin/ld \
	--with-sysroot=/ \
%endif
	--disable-nls --disable-shared \
	--target=%{CONFIGURE_TARGET} \
%else
	--program-suffix=%{binsuffix} \
	--enable-version-specific-runtime-libs \
%ifarch ia64
	--with-system-libunwind \
%else
	--without-system-libunwind \
%endif
%endif
%if "%{TARGET_ARCH}" == "powerpc"
	--with-cpu=default32 \
	--enable-secureplt \
	--with-long-double-128 \
%endif
%if "%{TARGET_ARCH}" == "powerpc64"
	--enable-secureplt \
	--with-long-double-128 \
%endif
%if "%{TARGET_ARCH}" == "i586"
	--with-cpu=generic \
%endif
%if "%{TARGET_ARCH}" == "x86_64"
	--with-cpu=generic \
%endif
%if "%{TARGET_ARCH}" == "s390"
        --with-tune=z9-109 --with-arch=z900 \
	--with-long-double-128 \
%endif
%if "%{TARGET_ARCH}" == "s390x"
        --with-tune=z9-109 --with-arch=z900 \
	--with-long-double-128 \
%endif
	--host=%{GCCDIST}

# COMMON-END

# Only run profiled bootstrap on archs where it works
#%ifarch %ix86 x86_64 ppc ppc64 ia64
#make profiledbootstrap BOOT_CFLAGS="$RPM_OPT_FLAGS" $PARALLEL
#%else
make bootstrap-lean BOOT_CFLAGS="$RPM_OPT_FLAGS" $PARALLEL
#%endif
#make -C gcc proto
make info
%if %{run_tests}
echo "Run testsuite"
(make -C %{GCCDIST}/libstdc++-v3 check-abi || true)
mv %{GCCDIST}/libstdc++-v3/testsuite/libstdc++.log %{GCCDIST}/libstdc++-v3/testsuite/libstdc++-abi.log
mv %{GCCDIST}/libstdc++-v3/testsuite/libstdc++.sum %{GCCDIST}/libstdc++-v3/testsuite/libstdc++-abi.sum
make -k check $PARALLEL || true
mkdir ../testresults
../contrib/test_summary > ../testresults/test_summary.txt
%endif

%install
# get Check to pick up man/info pages under /opt
%if %{gcc_for_opt}
manpath=%{_mandir}:%{_infodir}
export manpath
%endif

cd obj-%{GCCDIST}
# Work around tail/head -1 changes
export _POSIX2_VERSION=199209
export LIBRARY_PATH=$RPM_BUILD_ROOT%{libsubdir}:$RPM_BUILD_ROOT%{mainlibdirbi32}:$RPM_BUILD_ROOT%{mainlibdirbi64}
%if 0%{?building_libjava:1}
make -C %{GCCDIST}/libjava install DESTDIR=$RPM_BUILD_ROOT
make -C %{GCCDIST}/libffi install DESTDIR=$RPM_BUILD_ROOT
make -C gcc java.install-man DESTDIR=$RPM_BUILD_ROOT
%else
make install DESTDIR=$RPM_BUILD_ROOT
%endif
mkdir -p $RPM_BUILD_ROOT%{_libdir}

# Remove some useless .la files
for lib in libobjc libgfortran libgfortranbegin libmudflap libmudflapth \
    libstdc++ libsupc++; do
  rm -f $RPM_BUILD_ROOT%{versmainlibdir}/$lib.la
%if %{biarch}
%if %{build_primary_64bit}
  rm -f $RPM_BUILD_ROOT%{versmainlibdirbi32}/$lib.la
%else
  rm -f $RPM_BUILD_ROOT%{versmainlibdirbi64}/$lib.la
%endif
%endif
done
rm -f $RPM_BUILD_ROOT%{_libdir}/libffi.la
%if %{biarch}
%if %{build_primary_64bit}
  rm -f $RPM_BUILD_ROOT%{_prefix}/lib/libffi.la
%else
  rm -f $RPM_BUILD_ROOT%{_prefix}/lib64/libffi.la
%endif
%endif

%if %{biarch}
%if %{build_primary_64bit}
mkdir -p $RPM_BUILD_ROOT%{_prefix}/lib
%else
mkdir -p $RPM_BUILD_ROOT%{_prefix}/lib64
%endif
%endif

# LIBJAVA-DELETE-BEGIN
# Fix c++config.h for multilibs
cxxconfig="`find %{GCCDIST}/libstdc++-v3/include -name c++config.h`"
for i in `find %{GCCDIST}/[36]*/libstdc++-v3/include -name c++config.h 2>/dev/null`; do
  if ! diff -up $cxxconfig $i; then
    file_32=x
    file_64=x
    case $i in
      %{GCCDIST}/32/*)
        file_32=$i
        file_64=$cxxconfig
	;;
      %{GCCDIST}/64/*)
        file_32=$cxxconfig
	file_64=$i
	;;
    esac
    if ! ( test -f "$file_32" && test -f "$file_64" ); then
      echo "Urgs?"
      exit 1
    fi

    cat > $RPM_BUILD_ROOT%{_prefix}/include/c++/%{gcc_version}/%{GCCDIST}/bits/c++config.h <<EOF
#ifndef _CPP_CPPCONFIG_WRAPPER
#define _CPP_CPPCONFIG_WRAPPER 1
#include <bits/wordsize.h>
#if __WORDSIZE == 32
`cat $file_32`
#else
`cat $file_64`
#endif
#endif
EOF
    break
  fi
done
# LIBJAVA-DELETE-END

# Move shared libs around
%if %{versionspecificlibs}
%else
# libjava possibly breaks, ada is broken
for libname in \
%if %{build_libjava}
  libgcj libgij libgcjawt lib-gnu-java-awt-peer-gtk \
%endif
  ; do
  mv -f $RPM_BUILD_ROOT%{versmainlibdir}/$libname.* $RPM_BUILD_ROOT%{mainlibdir}/
%if %{biarch_libjava}
%if %{build_primary_64bit}
  mv -f $RPM_BUILD_ROOT%{versmainlibdirbi32}/$libname.* $RPM_BUILD_ROOT%{mainlibdirbi32}/
%else
  mv -f $RPM_BUILD_ROOT%{versmainlibdirbi64}/$libname.* $RPM_BUILD_ROOT%{mainlibdirbi64}/
%endif
%endif
done
# LIBJAVA-DELETE-BEGIN
# move shared libs from versionspecific dir to main libdir
for libname in \
%if %{build_fortran}
  libgfortran \
%endif
  libobjc libstdc++ libmudflap libmudflapth; do
  for lib in `find $RPM_BUILD_ROOT%{versmainlibdir} -maxdepth 1 -name $libname.so.*`; do
    mv $lib $RPM_BUILD_ROOT%{mainlibdir}/
  done
  ln -sf %{mainlibdir}/`readlink $RPM_BUILD_ROOT%{versmainlibdir}/$libname.so | sed -e 's/\(.*\.so\.[^\.]*\).*/\1/'`  \
         $RPM_BUILD_ROOT%{versmainlibdir}/$libname.so
%if %{biarch}
%if %{build_primary_64bit}
  for lib in `find $RPM_BUILD_ROOT%{versmainlibdirbi32} -maxdepth 1 -name "$libname.so.*"`; do
    mv $lib $RPM_BUILD_ROOT%{mainlibdirbi32}/
  done
  ln -sf %{mainlibdirbi32}/`readlink $RPM_BUILD_ROOT%{versmainlibdirbi32}/$libname.so | sed -e 's/\(.*\.so\.[^\.]*\).*/\1/'`  \
         $RPM_BUILD_ROOT%{versmainlibdirbi32}/$libname.so
%else
  for lib in `find $RPM_BUILD_ROOT%{versmainlibdirbi64} -maxdepth 1 -name "$libname.so.*"`; do
    mv $lib $RPM_BUILD_ROOT%{mainlibdirbi64}/
  done
  ln -sf %{mainlibdirbi64}/`readlink $RPM_BUILD_ROOT%{versmainlibdirbi64}/$libname.so | sed -e 's/\(.*\.so\.[^\.]*\).*/\1/'`  \
         $RPM_BUILD_ROOT%{versmainlibdirbi64}/$libname.so
%endif
%endif
done
%endif

# Move libgcc_s around
rm -f $RPM_BUILD_ROOT/%{_lib}/libgcc_s.so
ln -sf /%{_lib}/libgcc_s.so.%{libgcc_s} $RPM_BUILD_ROOT%{versmainlibdir}/libgcc_s.so
chmod a+x $RPM_BUILD_ROOT/%{_lib}/libgcc_s.so.%{libgcc_s}
%if %{biarch}
%if %{build_primary_64bit}
rm -f $RPM_BUILD_ROOT/lib/libgcc_s.so
ln -sf /lib/libgcc_s.so.%{libgcc_s} $RPM_BUILD_ROOT%{versmainlibdirbi32}/libgcc_s.so
ln -sf /lib/libgcc_s.so.%{libgcc_s} $RPM_BUILD_ROOT%{versmainlibdirbi32}/libgcc_s_32.so
chmod a+x $RPM_BUILD_ROOT/lib/libgcc_s.so.%{libgcc_s}
%else
# 32-bit biarch systems
rm -f $RPM_BUILD_ROOT/lib64/libgcc_s.so
ln -sf /lib64/libgcc_s.so.%{libgcc_s} $RPM_BUILD_ROOT%{versmainlibdirbi64}/libgcc_s.so
ln -sf /lib64/libgcc_s.so.%{libgcc_s} $RPM_BUILD_ROOT%{versmainlibdirbi64}/libgcc_s_64.so
chmod a+x $RPM_BUILD_ROOT/lib64/libgcc_s.so.%{libgcc_s}
%endif
%endif

%if %{build_ada}
mv $RPM_BUILD_ROOT%{libsubdir}/adalib/lib*-*.so $RPM_BUILD_ROOT%{_libdir}
ln -sf %{_libdir}/$(cd $RPM_BUILD_ROOT%{_libdir} && echo libgnarl-*.so) $RPM_BUILD_ROOT%{libsubdir}/adalib/libgnarl.so
ln -sf %{_libdir}/$(cd $RPM_BUILD_ROOT%{_libdir} && echo libgnat-*.so) $RPM_BUILD_ROOT%{libsubdir}/adalib/libgnat.so
chmod a+x $RPM_BUILD_ROOT%{_libdir}/libgna*-*.so
# LIBJAVA-DELETE-END
%endif

rm -f $RPM_BUILD_ROOT%{_prefix}/bin/c++%{binsuffix}

%if %{biarch}
%if %{build_primary_64bit}
# move around some libs that end in wrong paths
pushd .
mkdir -p $RPM_BUILD_ROOT%{_prefix}/lib
mkdir -p $RPM_BUILD_ROOT%{_libdir}/32
(cd $RPM_BUILD_ROOT%{_libdir}/32; tar cf - .) | (cd $RPM_BUILD_ROOT%{_prefix}/lib ; tar xf -)
rm -rf $RPM_BUILD_ROOT%{_libdir}/32
%if 0%{?!building_libjava:1}
ln -s %{_prefix}/lib $RPM_BUILD_ROOT%{_libdir}/32
rm -rf $RPM_BUILD_ROOT/%{_lib}/32
ln -s /lib $RPM_BUILD_ROOT/%{_lib}/32
%endif
popd
%else
# 32-bit biarch systems
# move around some libs that end in wrong paths
pushd .
mkdir -p $RPM_BUILD_ROOT%{_prefix}/lib64
mkdir -p $RPM_BUILD_ROOT%{_libdir}/64
(cd $RPM_BUILD_ROOT%{_libdir}/64; tar cf - .) | (cd $RPM_BUILD_ROOT%{_prefix}/lib64 ; tar xf -)
rm -rf $RPM_BUILD_ROOT%{_libdir}/64
%if 0%{?!building_libjava:1}
ln -s %{_prefix}/lib $RPM_BUILD_ROOT%{_libdir}/64
%endif
popd
%endif
%endif

# Remove some crap from the .la files:
for l in `find $RPM_BUILD_ROOT -name '*.la'`; do
  echo "changing $l"
  sed -e '/^dependency_libs/s| -L%{_builddir}/[^ ]*||g' \
      -e '/^dependency_libs/s| -L/usr/%{GCCDIST}/bin||g' \
      -e '/^dependency_libs/s|-lm \(-lm \)*|-lm |' \
      -e '/^dependency_libs/s|-L[^ ]* ||g' \
      -e '/^dependency_libs/s|%{libsubdir}/\([^.]*\)\.la |%{_libdir}/\1\.la |g' \
%if %{biarch}
%if %{build_primary_64bit}
      -e '/^libdir/s|%{_libdir}/32|%{_prefix}/lib|' \
      -e '/^libdir/s|lib64/\.\./||' \
%else
      -e '/^libdir/s|%{_libdir}/64|%{_prefix}/lib64|' \
%endif
%endif
      < $l  > $l.new
  mv $l.new $l
done
%if %{gcc_for_opt}
%ifarch x86_64
perl  -pi -e "s|^(.*elf_i386.*)|\1 %{m32:-rpath=/opt/gcc33/lib} %{\!m32:-rpath=/opt/gcc33/lib64}|;"  $RPM_BUILD_ROOT%{_prefix}/lib64/gcc/x86_64-suse-linux/3.3/specs
%endif
%endif

%if %{run_tests} 
cp `find . -name "*.sum"` ../testresults/
cp `find . -name "*.log"  \! -name "config.log" |grep -v 'acats/tests' ` ../testresults/
chmod 644 ../testresults/*
%endif
# Delete precompiled headers
find $RPM_BUILD_ROOT%{_prefix}/include/c++ \
  -type d -name "*.gch" | xargs rm -rf
# Find C++ and Java headers
find $RPM_BUILD_ROOT%{_prefix}/include/c++ \
  -regex ".*/\(org\|gcj\|gnu\|java\|javax\)" -prune \
  -o \( -type d -printf "%%%%dir " , \
        -printf "%{_prefix}/include/c++/%%P\n" \) > ../c++-headers
# Remove files that we do not need to clean up filelist
rm -f $RPM_BUILD_ROOT%{_prefix}/bin/%{GCCDIST}-*
rm -rf $RPM_BUILD_ROOT%{libsubdir}/install-tools
rm -rf $RPM_BUILD_ROOT%{libsubdir}/install-tools
rm -rf $RPM_BUILD_ROOT%{_libdir}/pkgconfig/libgcj.pc
rm -rf $RPM_BUILD_ROOT%{libsubdir}/include/root
rm -f $RPM_BUILD_ROOT%{libsubdir}/include/curses.h
rm -rf $RPM_BUILD_ROOT%{libsubdir}/include/asm-*
rm -rf $RPM_BUILD_ROOT%{libsubdir}/include/linux
rm -rf $RPM_BUILD_ROOT%{libsubdir}/include/sound
rm -f $RPM_BUILD_ROOT%{libsubdir}/include/ncurses.h
rm -f $RPM_BUILD_ROOT%{libsubdir}/include/stdio.h
rm -f $RPM_BUILD_ROOT%{libsubdir}/include/zutil.h
rm -rf $RPM_BUILD_ROOT%{libsubdir}/include/X11
rm -rf $RPM_BUILD_ROOT%{libsubdir}/include/bits
rm -f $RPM_BUILD_ROOT%{libsubdir}/include/obstack.h
rm -f $RPM_BUILD_ROOT%{libsubdir}/include/spe.h
rm -rf $RPM_BUILD_ROOT%{libsubdir}/include/bits
rm -rf $RPM_BUILD_ROOT%{libsubdir}/include/sys
rm -f  $RPM_BUILD_ROOT%{_infodir}/dir
rm -f $RPM_BUILD_ROOT%{_prefix}/bin/gccbug%{binsuffix}
%if %{build_libjava}
# gcj -static doesn't work properly anyway, unless using --whole-archive
# let's save the space instead.
find $RPM_BUILD_ROOT -name libgcj.a -o -name lib-gnu-java-awt-peer-gtk.a \
                     -o -name libgjsmalsa.a \
                     -o -name libgij.a -o -name libgcjawt.a | xargs rm -f

find $RPM_BUILD_ROOT -name libgcj.spec | xargs \
  sed -i -e 's/lib: /&%%{static:%%eJava programs cannot be linked statically}/'

mv $RPM_BUILD_ROOT%{libsubdir}/include/libffi/ffitarget.h $RPM_BUILD_ROOT%{_prefix}/include/
rm -r $RPM_BUILD_ROOT%{libsubdir}/include/libffi
%endif
%if %{build_java}
%if !%{build_libjava}
rm $RPM_BUILD_ROOT%{_mandir}/man1/gcj-dbtool%{binsuffix}.1
rm $RPM_BUILD_ROOT%{_mandir}/man1/gij%{binsuffix}.1
rm $RPM_BUILD_ROOT%{_mandir}/man1/grmic%{binsuffix}.1
rm $RPM_BUILD_ROOT%{_mandir}/man1/grmiregistry%{binsuffix}.1
%endif
# fastjar is separate now
rm -f $RPM_BUILD_ROOT%{_prefix}/bin/fastjar%{binsuffix}
rm -f $RPM_BUILD_ROOT%{_prefix}/bin/grepjar%{binsuffix}
rm -f $RPM_BUILD_ROOT%{_infodir}/fastjar.info*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/fastjar%{binsuffix}.1
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/grepjar%{binsuffix}.1
%endif
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/fsf-funding.7
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/gfdl.7
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/gpl.7
rm -f $RPM_BUILD_ROOT%{_libdir}/libiberty.a
%if %{build_nof}
rm -f $RPM_BUILD_ROOT%{_prefix}/lib/nof/libiberty.a
%endif
%if %{biarch}
%if %{build_primary_64bit}
rm -f $RPM_BUILD_ROOT%{_prefix}/lib/libiberty.a
%else
rm -f $RPM_BUILD_ROOT%{_prefix}/lib64/libiberty.a
%endif
%endif

# Move mudflap header
%if 0%{!?building_libjava:1}
mv $RPM_BUILD_ROOT/usr/include/mf-runtime.h $RPM_BUILD_ROOT%{libsubdir}/include/
rm $RPM_BUILD_ROOT%{_mandir}/man1/jv-convert%{binsuffix}.1
%endif

# For building libjava only we need to delete other manpages
%if 0%{?building_libjava:1}
rm $RPM_BUILD_ROOT%{_prefix}/bin/addr2name.awk%{binsuffix}
rm $RPM_BUILD_ROOT%{_mandir}/man1/gcj%{binsuffix}.1
rm $RPM_BUILD_ROOT%{_mandir}/man1/gcjh%{binsuffix}.1
rm $RPM_BUILD_ROOT%{_mandir}/man1/gjnih%{binsuffix}.1
rm $RPM_BUILD_ROOT%{_mandir}/man1/jcf-dump%{binsuffix}.1
rm $RPM_BUILD_ROOT%{_mandir}/man1/jv-scan%{binsuffix}.1
%endif

# Delete some files...
%if %{versionspecificlibs}
%if %{build_libjava}
rm $RPM_BUILD_ROOT%{_libdir}/logging.properties
rm $RPM_BUILD_ROOT%{_libdir}/security/classpath.security
rm $RPM_BUILD_ROOT%{_libdir}/security/libgcj.security
%endif
rm $RPM_BUILD_ROOT%{_infodir}/*.info*
rm $RPM_BUILD_ROOT%{_prefix}/share/locale/*/LC_MESSAGES/*.mo
%endif

# LIBJAVA-DELETE-BEGIN
cd ..
%find_lang gcc41-locale --all-name

%post info
%if !%{gcc_for_opt}
%install_info --info-dir=%{_infodir} %{_infodir}/cpp.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/cppinternals.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/gcc.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/gccint.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/gccinstall.info.gz
%if %{build_fortran} 
%install_info --info-dir=%{_infodir} %{_infodir}/gfortran.info.gz
%endif
%if %{build_java}
%install_info --info-dir=%{_infodir} %{_infodir}/gcj.info.gz
%endif
%if %{build_ada}
%install_info --info-dir=%{_infodir} %{_infodir}/gnat-style.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/gnat_rm.info.gz
%install_info --info-dir=%{_infodir} --section="GNU Ada tools" --entry="* GNAT User's Guide: (gnat_ug_unx). GNAT User's Guide for Unix Platforms" %{_infodir}/gnat_ug_unx.info.gz
%endif
%endif

%postun info
%if !%{gcc_for_opt}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/cpp.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/cppinternals.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gcc.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gccint.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gccinstall.info.gz
%if %{build_fortran}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gfortran.info.gz
%endif
%if %{build_java}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gcj.info.gz
%endif
%if %{build_ada}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gnat-style.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gnat_rm.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gnat_ug_unx.info.gz
%endif
%endif

%files
%defattr(-,root,root)
%dir %{_libdir}/gcc
%dir %{_libdir}/gcc/%{GCCDIST}
%dir %{libsubdir}
%dir %{libsubdir}/include
%if %{biarch}
%if %{build_primary_64bit}
# This link is essential for correct execution
%{_libdir}/32
/%{_lib}/32
%dir %{libsubdir}/32
%else
%{_libdir}/64
%dir %{libsubdir}/64
%endif
%endif
%if %{build_nof}
%dir %{libsubdir}/nof
%endif
%{_prefix}/bin/gcc%{binsuffix}
%{_prefix}/bin/gcov%{binsuffix}
%{libsubdir}/collect2
%{libsubdir}/include/README
%{libsubdir}/include/float.h
%{libsubdir}/include/iso646.h
%{libsubdir}/include/limits.h
%{libsubdir}/include/stdarg.h
%{libsubdir}/include/stdbool.h
%{libsubdir}/include/stddef.h
%{libsubdir}/include/syslimits.h
%{libsubdir}/include/unwind.h
%{libsubdir}/include/varargs.h
%ifarch ppc ppc64
%{libsubdir}/include/altivec.h
%{libsubdir}/include/ppc-asm.h
%endif
%ifarch ia64
%{libsubdir}/include/ia64intrin.h
%endif
%ifarch %arm
%{libsubdir}/include/mmintrin.h
%endif
%ifarch %ix86 x86_64
%{libsubdir}/include/mm3dnow.h
%{libsubdir}/include/mmintrin.h
%{libsubdir}/include/ammintrin.h
%{libsubdir}/include/bmmintrin.h
%{libsubdir}/include/emmintrin.h
%{libsubdir}/include/pmmintrin.h
%{libsubdir}/include/xmmintrin.h
%{libsubdir}/include/tmmintrin.h
%{libsubdir}/include/mm_malloc.h
%{libsubdir}/include/mmintrin-common.h
%endif
%{libsubdir}/include/mf-runtime.h
%versmainlib *crt*.o
%versmainlib libgcc*.a
%versmainlib libgcov.a
%versmainlib libgcc_s*.so
%versmainlib libmudflap.a
%versmainlib libmudflap.so
%versmainlib libmudflapth.a
%versmainlib libmudflapth.so
%doc %{_mandir}/man1/gcc%{binsuffix}.1.gz
%doc %{_mandir}/man1/gcov%{binsuffix}.1.gz

%if %{separate_biarch}
%files -n gcc41%{separate_biarch_suffix}
%defattr(-,root,root)
%versbiarchlib *crt*.o
%versbiarchlib libgcc*.a
%versbiarchlib libgcov.a
%versbiarchlib libgcc_s*.so
%versbiarchlib libmudflap.a
%versbiarchlib libmudflap.so
%versbiarchlib libmudflapth.a
%versbiarchlib libmudflapth.so
%endif

%if !%{versionspecificlibs}
%files locale -f gcc41-locale.lang
%endif

%files c++
%defattr(-,root,root)
%dir %{_libdir}/gcc
%dir %{_libdir}/gcc/%{GCCDIST}
%dir %{libsubdir}
%{_prefix}/bin/g++%{binsuffix}
%doc %{_mandir}/man1/g++%{binsuffix}.1.gz
%{libsubdir}/cc1plus

%files -n libstdc++41-devel -f c++-headers
%defattr(-,root,root)
%versmainlib libstdc++.a
%versmainlib libstdc++.so
%versmainlib libsupc++.a

%if %{separate_biarch}
%files -n libstdc++41-devel%{separate_biarch_suffix}
%defattr(-,root,root)
%versbiarchlib libstdc++.a
%versbiarchlib libstdc++.so
%versbiarchlib libsupc++.a
%endif

%files -n libstdc++41-doc
%defattr(-,root,root)
%doc libstdc++-v3/docs/html

%files -n libgcc41
%defattr(-,root,root)
%if %{versionspecificlibs}
%versmainlib libgcc_s.so.%{libgcc_s}
%else
# not versionspecificlibs
/%{_lib}/libgcc_s.so.%{libgcc_s}
%if %{build_nof}
%dir /lib/nof
/lib/nof/libgcc_s.so.%{libgcc_s}
%endif
%if %{biarch}
%if %{build_primary_64bit}
%if !%{separate_bi32}
/lib/libgcc_s.so.%{libgcc_s}
%endif
%else
%if !%{separate_bi64}
/lib64/libgcc_s.so.%{libgcc_s}
%endif
%endif
%endif
%endif

%if %{separate_bi64}
%files -n libgcc41-64bit
%defattr(-,root,root)
%if %{versionspecificlibs}
%versbiarchlib libgcc_s.so.%{libgcc_s}
%else
/lib64/libgcc_s.so.%{libgcc_s}
%endif
%endif

%if %{separate_bi32}
%files -n libgcc41-32bit
%defattr(-,root,root)
%if %{versionspecificlibs}
%versbiarchlib libgcc_s.so.%{libgcc_s}
%else
/lib/libgcc_s.so.%{libgcc_s}
%endif
%endif

%files -n libstdc++41
%defattr(-,root,root)
%if %{build_nof}
%dir %{noflibdir}
%endif
%mainlib libstdc++.so.*

%if %{separate_biarch}
%files -n libstdc++41%{separate_biarch_suffix}
%defattr(-,root,root)
%biarchlib libstdc++.so.*
%endif

%if %{build_fortran}
%files fortran
%defattr(-,root,root)
%{_prefix}/bin/gfortran%{binsuffix}
%{libsubdir}/f951
%versmainlib libgfortran.a
%versmainlib libgfortran.so
%versmainlib libgfortranbegin.a
%doc %{_mandir}/man1/gfortran%{binsuffix}.1.gz

%if %{separate_biarch}
%files fortran%{separate_biarch_suffix}
%defattr(-,root,root)
%versbiarchlib libgfortran.a
%versbiarchlib libgfortran.so
%versbiarchlib libgfortranbegin.a
%endif

%files -n libgfortran41
%defattr(-,root,root)
%mainlib libgfortran.so.*

%if %{separate_biarch}
%files -n libgfortran41%{separate_biarch_suffix}
%defattr(-,root,root)
%biarchlib libgfortran.so.*
%endif
%endif

%files -n libmudflap41
%defattr(-,root,root)
%mainlib libmudflap.so.*
%mainlib libmudflapth.so.*

%if %{separate_biarch}
%files -n libmudflap41%{separate_biarch_suffix}
%defattr(-,root,root)
%biarchlib libmudflap.so.*
%biarchlib libmudflapth.so.*
%endif

%if !%{versionspecificlibs}
%files info
%defattr(-,root,root)
%doc %{_infodir}/cpp.info*.gz
%doc %{_infodir}/cppinternals.info*.gz
%doc %{_infodir}/gcc.info*.gz
%doc %{_infodir}/gccint.info*.gz
%doc %{_infodir}/gccinstall.info*.gz
%if %{build_fortran}
%doc %{_infodir}/gfortran.info*.gz
%endif
%if %{build_java}
%doc %{_infodir}/gcj.info*.gz
%endif
%if %{build_ada}
%doc %{_infodir}/gnat-style.info*gz
%doc %{_infodir}/gnat_rm.info*gz
%doc %{_infodir}/gnat_ugn_unw.info*gz
%endif
%endif

%files -n cpp41
%defattr(-,root,root)
%dir %{_libdir}/gcc
%dir %{_libdir}/gcc/%{GCCDIST}
%dir %{libsubdir}
%{_prefix}/bin/cpp%{binsuffix}
%{libsubdir}/cc1
#%{libsubdir}/specs
%doc %{_mandir}/man1/cpp%{binsuffix}.1.gz

%files objc
%defattr(-,root,root)
%{libsubdir}/cc1obj
%{libsubdir}/include/objc
%versmainlib libobjc.a
%versmainlib libobjc.so

%if %{separate_biarch}
%files objc%{separate_biarch_suffix}
%defattr(-,root,root)
%versbiarchlib libobjc.a
%versbiarchlib libobjc.so
%endif

%files -n libobjc41
%defattr(-,root,root)
%mainlib libobjc.so.*

%if %{separate_biarch}
%files -n libobjc41%{separate_biarch_suffix}
%defattr(-,root,root)
%biarchlib libobjc.so.*
%endif

%if %{build_objcp}
%files obj-c++
%defattr(-,root,root)
%{libsubdir}/cc1objplus
%endif

%if %{build_ada}
%files ada
%defattr(-,root,root)
%dir %{_libdir}/gcc
%dir %{_libdir}/gcc/%{GCCDIST}
%dir %{libsubdir}
%{_prefix}/bin/gnat*
%{_prefix}/bin/gpr*
%{libsubdir}/adainclude
%dir %{libsubdir}/adalib
%{libsubdir}/adalib/*.ali
%{libsubdir}/adalib/*.a
%{libsubdir}/adalib/libgnarl.so
%{libsubdir}/adalib/libgnat.so
%{libsubdir}/adalib/g-trasym.o
%{libsubdir}/gnat1

%files -n libada41
%defattr(-,root,root)
# Ada is not multilibbed
%{mainlibdir}/libgnarl-*.so
%{mainlibdir}/libgnat-*.so
%endif

%if %{build_java}
%files java
%defattr(-,root,root)
%{_prefix}/bin/gcj%{binsuffix}
%{_prefix}/bin/gcjh%{binsuffix}
%{_prefix}/bin/gjnih%{binsuffix}
%{_prefix}/bin/jcf-dump%{binsuffix}
%{_prefix}/bin/jv-scan%{binsuffix}
%{libsubdir}/jc1
%{libsubdir}/jvgenmain
%doc %{_mandir}/man1/gcj%{binsuffix}.1.gz
%doc %{_mandir}/man1/gcjh%{binsuffix}.1.gz
%doc %{_mandir}/man1/gjnih%{binsuffix}.1.gz
%doc %{_mandir}/man1/jcf-dump%{binsuffix}.1.gz
%doc %{_mandir}/man1/jv-scan%{binsuffix}.1.gz
%endif
# LIBJAVA-DELETE-END

%if %{build_java}
%if %{build_libjava}
%files -n libgcj41
%defattr(-,root,root)
%dir %{_libdir}/gcj-%{gcc_version}
%{_prefix}/share/java/libgcj-%{gcc_version}.jar
%{_libdir}/gcj-%{gcc_version}/classmap.db
%if !%{versionspecificlibs}
%dir %{_libdir}/security
%{_libdir}/security/classpath.security
%{_libdir}/security/libgcj.security
%endif
# We usually do not multilib libjava
%if %{biarch_libjava}
%mainlib libgcj.so.*
%mainlib libgij.so.*
%mainlib libgcjawt.so.*
%mainlib lib-gnu-java-awt-peer-gtk.so.*
# these libs may get dlopened by their .la/.so name
%mainlib libgcjawt.la
%mainlib libgcjawt.so
%mainlib lib-gnu-java-awt-peer-gtk.la
%mainlib lib-gnu-java-awt-peer-gtk.so
%else
%{mainlibdir}/libgcj.so.*
%{mainlibdir}/libgij.so.*
%{mainlibdir}/libgcjawt.so.*
%{mainlibdir}/lib-gnu-java-awt-peer-gtk.so.*
# these libs may get dlopened by their .la/.so name
%{mainlibdir}/libgcjawt.la
%{mainlibdir}/libgcjawt.so
%{mainlibdir}/lib-gnu-java-awt-peer-gtk.la
%{mainlibdir}/lib-gnu-java-awt-peer-gtk.so
%endif
%if !%{versionspecificlibs}
%{_libdir}/logging.properties
%endif

%files -n libgcj41-devel
%defattr(-,root,root)
%dir %{_prefix}/include/c++
%dir %{libsubdir}
%dir %{libsubdir}/include
%dir %{gxxinclude}
%{libsubdir}/include/jawt.h
%{libsubdir}/include/jawt_md.h
%{libsubdir}/include/jni.h
%{libsubdir}/include/jni_md.h
%{libsubdir}/include/jvmpi.h
%{gxxinclude}/gnu
%{gxxinclude}/gcj
%{gxxinclude}/java
%{gxxinclude}/javax
%{gxxinclude}/org
%{libsubdir}/include/gcj
%if %{biarch_libjava}
%mainlib libgcj.la
%mainlib libgcj.so
%mainlib libgcj.spec
%mainlib libgij.la
%mainlib libgij.so
%else
%{mainlibdir}/libgcj.la
%{mainlibdir}/libgcj.so
%{mainlibdir}/libgcj.spec
%{mainlibdir}/libgij.la
%{mainlibdir}/libgij.so
%endif

%files -n gcc41-gij
%defattr(-,root,root)
%{_prefix}/bin/grmic%{binsuffix}
%{_prefix}/bin/grmiregistry%{binsuffix}
%{_prefix}/bin/jv-convert%{binsuffix}
%{_prefix}/bin/gcj-dbtool%{binsuffix}
%{_prefix}/bin/gij%{binsuffix}
%doc %{_mandir}/man1/gij%{binsuffix}.1.gz
%doc %{_mandir}/man1/gcj-dbtool%{binsuffix}.1.gz
%doc %{_mandir}/man1/grmic%{binsuffix}.1.gz
%doc %{_mandir}/man1/grmiregistry%{binsuffix}.1.gz
%doc %{_mandir}/man1/jv-convert%{binsuffix}.1.gz

%files -n libffi41
%defattr(-,root,root)
%mainlib libffi.so.*

%if %{separate_biarch}
%files -n libffi41%{separate_biarch_suffix}
%defattr(-,root,root)
%biarchlib libffi.so.*
%endif

%files -n libffi41-devel
%defattr(-,root,root)
%{_prefix}/include/ffi.h
%{_prefix}/include/ffitarget.h
%mainlib libffi.so
%mainlib libffi.a

%if %{separate_biarch}
%files -n libffi41-devel%{separate_biarch_suffix}
%defattr(-,root,root)
%biarchlib libffi.so
%biarchlib libffi.a
%endif
%endif
%endif

%if %{run_tests}
%files -n gcc41-testresults
%defattr(-,root,root)
%doc testresults/test_summary.txt
%doc testresults/*.sum
%doc testresults/*.log
%endif

%changelog
* Thu May 22 2014 rguenther@suse.com
- Require/provide libgcc_s1 instead of libgcc1.
* Wed Jun 26 2013 coolo@suse.com
- strip -grecord-gcc-switches from optflag
* Sat Jul 28 2012 aj@suse.de
- Fix build with glibc 2.16 (struct siginfo is not exported anymore).
* Fri Jul 20 2012 rguenther@suse.com
- BuildRequire makeinfo only where appropriate.
* Fri Jun  1 2012 adrian@suse.de
- do not build this compiler on arm plattform
* Tue Apr 24 2012 rguenther@suse.com
- Add xorg-x11-devel BuildRequires for openSUSE 12.2+
* Fri Feb  3 2012 rguenther@suse.com
- Add README.First-for.SuSE.packagers and baselibs.conf as sources.
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Fri Oct 21 2011 mls@suse.de
- do not use /usr/src/packages in specfile
* Mon Dec  6 2010 rguenther@novell.com
- Provide/require libgcc%%{libgcc_s} and libstdc++6  [bnc#657604]
* Thu Apr 29 2010 rguenther@novell.com
- Drop cross-avr-gcc.
* Wed Apr 14 2010 rguenther@novell.com
- Fix cross-avr-patch-dwarf.patch.
* Fri Nov 20 2009 rguenther@suse.de
- Re-diff patches to apply without fuzz.
- Avoid obsoleting/providing ourselves.
* Mon Aug 24 2009 rguenther@suse.de
- Add patch for PR31499.  [bnc#488140]
* Mon May 11 2009 matz@suse.de
- Add patch for internal compiler error or s390x.  [bnc #415378]
- Add patch for miscompile with -msecure-plt.  [bnc #465381]
- Fix fortran-matmul.diff to not ICE.
* Mon May 11 2009 rguenther@suse.de
- Add patch for PR28460.
* Thu May  7 2009 rguenther@suse.de
- Add ia64 baselib for x86 libgfortran.
* Mon Apr 20 2009 rguenther@suse.de
- Downgrade to SLE10 head version plus patches that accumulated
  in STABLE.  May serve as a base for fixing bnc#485521.
- Add patch to fix makeinfo detection.
- Add patch to fix ld version detection.
- Fix ldconfig calls.
* Sat Apr 18 2009 rguenther@suse.de
- Adjust Ada BuildRequires check.
* Wed Apr 15 2009 ro@suse.de
- buildfix: refresh patch gcc41-ia64-stack-protector.patch
* Mon Mar 16 2009 rguenther@suse.de
- Only ia64 needs libunwind-devel.
* Fri Feb  6 2009 rguenther@suse.de
- Fix obsoletes for libgcj-64bit.
* Fri Jan 30 2009 rguenther@suse.de
- Add Obsoletes for ppc -> ppc64 update.  [bnc#437293]
* Fri Dec  5 2008 dmueller@suse.de
- Build crtend*.o without unwind tables.
* Fri Nov 21 2008 ro@suse.de
- update check-build.sh
* Thu Jun 12 2008 rguenther@suse.de
- Update to gcc-4_1-branch head (r136697).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Feb 15 2008 dmueller@suse.de
- fix rpmlintrc (it has to be valid python code)
* Fri Feb 15 2008 rguenther@suse.de
- Add rpmlintrc for gcc41.
* Tue Oct 30 2007 rguenther@suse.de
- Update to gcc-4_1-branch head (r129775).
* Mon Oct  1 2007 rguenther@suse.de
- Add patch to add -fpreserve-function-arguments.  [#326866]
* Fri Aug 10 2007 matz@suse.de
- Remove include/sound directory, as it now also contains fixed
  includes.
* Tue Jul 31 2007 matz@suse.de
- Don't build the cross icecream backends for 4.1. [#295509]
* Tue Jul 24 2007 rguenther@suse.de
- Update to gcc-4_1-branch head (r126874).
* Tue Jun 12 2007 rguenther@suse.de
- Add perl BuildRequires.
- Fix dependencies in libgcj libtool files.
* Fri May 25 2007 rguenther@suse.de
- Collect translations with %%find_lang.
* Wed May 23 2007 rguenther@suse.de
- Make testresults non-executable.
* Mon May 21 2007 rguenther@suse.de
- Update to SVN branch head (r124895).
- Use profiledbootstrap where appropriate.
* Mon Apr 30 2007 rguenther@suse.de
- Update to SVN branch head (r124295).
- Do not package libstdc++ precompiled headers.
- Add unzip BuildRequires for building libjava.
* Fri Apr 13 2007 rguenther@suse.de
- Update to SVN branch head (r123784).
- Add patch to reorder early uninitialized warning pass.
- Add %%post/%%postun %%run_ldconfig to library packages.
* Thu Mar 29 2007 rguenther@suse.de
- Adjust BuildRequires for cross packages.
* Mon Mar 26 2007 rguenther@suse.de
- Add zlib-devel BuildRequires.
* Fri Mar  2 2007 rguenther@suse.de
- Update to SVN branch head (r122476).
- Add patch for PR29512.
* Tue Feb 20 2007 rguenther@suse.de
- Update to SVN branch head (r122090).
- Add patch for PR29558.
- Remove bogus binutils version check from micro-cross.spec.in.
- Add patch to fix libstdc++-v3 binutils version check.
* Mon Feb 19 2007 schwab@suse.de
- Remove stack notes hack.
* Tue Feb  6 2007 rguenther@suse.de
- Add patch for PR20218, visibility fixes.
- Add patch for wrong parentheses warnings.
- Filter -ffortify and -fstack-protector from RPM_OPT_FLAGS.
* Tue Feb  6 2007 jw@suse.de
- typo in binutils check fixed.
* Mon Jan 29 2007 jw@suse.de
- cross-avr now checks the binutils changelog rather than an
  exact version match.
* Mon Jan 22 2007 rguenther@suse.de
- Fix building ada with gcc42 in beta.
- Include ada in testing.
- Do not package libffi.la.
- Add patches for AMD Family 10 and Power6 support.
* Mon Jan 15 2007 rguenther@suse.de
- Update to SVN branch head (r120791).
* Mon Jan  8 2007 schwab@suse.de
- Add fix for PR30230.
* Fri Dec 22 2006 jw@suse.de
- added versioned dependency for cross-avr-binutils to
  micro-cross.spec.in [230535]
* Sun Dec 10 2006 schwab@suse.de
- Fix prologue generation when many registers need to be spilled
  [#224153].
* Wed Nov 29 2006 rguenther@suse.de
- Update to SVN branch head.
- Add patch for Fate #300738.  [#159446]
- Add patch for PR29166.  [#224153]
* Fri Nov 17 2006 rguenther@suse.de
- Fix gcc41-fortran-{32,64}bit and gcc41-objc-{32,64}bit dependencies.
* Wed Nov 15 2006 jw@suse.de
- Added cross-avr patches found on freebsd.org [#220253]
* Wed Nov 15 2006 rguenther@suse.de
- Update to SVN branch head, fixes PR21032.
- Add patches for PR28217, PR28888, PR29753 and PR29788.
- Make gcc41-java and libgcj41-devel cross-dependencies independent
  of release numbers.  [#214268]
- Remove left-over dependency from libstdc++41-devel on gcc41.
* Mon Nov 13 2006 rguenther@suse.de
- Add patch for PR29797, fixes OpenOffice miscompilation on
  ppc.  [#198243]
* Thu Nov  9 2006 rguenther@suse.de
- Update to SVN branch head, fixes PR29695.
* Wed Nov  1 2006 rguenther@suse.de
- Update to SVN branch head, fixes PR29631 and PR28970.
- Add patch for PR28545.
* Tue Oct 24 2006 rguenther@suse.de
- Update to SVN branch head, fixes libzypp build on s390x.
- Re-enable MNI instruction support.
- Add patch to revert the fix for PR28506, fixes mjpegtools build.
* Wed Oct 18 2006 rguenther@suse.de
- Update to SVN branch head, fixes PR29119, PR29091 and PR28960.
* Fri Oct 13 2006 rguenther@suse.de
- Update to SVN branch head, fixes PR29154.
- Disable MNI instruction support again.
* Mon Oct  2 2006 matz@suse.de
- Fix PR29319 conservatively.  [s390x ICE]
* Tue Sep 26 2006 schwab@suse.de
- Fix static linking.
* Mon Sep 25 2006 rguenther@suse.de
- Merge fixes for #189571 and #199137 from SLE10-SP1 branch.
- Add patch to handle dwarf3 codes to support new glibc unwinding.
- Add patch for PR26208, unwinding from signal context.
- Add patch to support FORTIFY_SOURCE for strncat.
- Add patches for PR26881 and PR28755.  [#201515]
- Add patch to add MNI instruction support.
* Tue Sep 19 2006 rguenther@suse.de
- Update to SVN branch head.
- New gcc41-gij package.
- Do not package addr2name.
- Package jv-convert-4.1 manpage.
- Add patch to avoid -mtune=generic regression.
* Wed Sep 13 2006 rguenther@suse.de
- Update to SVN branch head.
- Enable gfortran testing.
* Tue Aug 29 2006 rguenther@suse.de
- Update to SVN branch head.  Fixes [#187184].
- Remove patch for bogus warning which is fixed upstream already.
- Fix URL for bugreporting, use http://bugs.opensuse.org instead of
  http://www.suse.de/feedback.
- No longer package gccbug script which led to feedback@suse.de which no
  longer exists.
- Run the testsuite from the libgcj package and package results
  in gcc41-testresults.
* Mon Aug 21 2006 rguenther@suse.de
- Update to SVN branch head.
- Add patch to allow stack protector inside the kernel.
- Generate libgcj spec file from gcc spec file.
- Clean up configure target machinery.
* Tue Aug 15 2006 rguenther@suse.de
- Clean up target architecture discovery.
- Add separate spec file for building libgcj.
* Tue Aug 15 2006 rguenther@suse.de
- Split libmudflap package from gcc-mudflap.
- Integrate gcc-mudflap into gcc package.
- Split 32bit/64bit package from gcc package.
- Allow disabling of libjava build.
* Thu Aug  3 2006 schwab@suse.de
- Fix missing stack notes.
* Mon Jul 31 2006 rguenther@suse.de
- Update to SVN branch head.
- Bump hppa libgcc so version to 4.
- Include conditionals for openSUSE::Base.
- Clean up remaining things in the file lists.
* Thu Jul 20 2006 rguenther@suse.de
- Rename all packages.  Use provides to handle update and
  same major .so version libraries from different packages.
* Mon Jul 17 2006 rguenther@suse.de
- Rename to gcc41.
- Install with suffix -4.1 for all binaries.
- No longer package protoize.
- No longer package cc, c++ and /lib/cpp.
- Make (some) devel packages use the package suffix.
- No longer provide c_compiler and c++_compiler.
* Fri Jul 14 2006 rguenther@suse.de
- Move all info files to gcc-info package.
* Wed Jul 12 2006 rguenther@suse.de
- Move development libraries to version specific directories.
- Move libstdc++ locales to gcc-locale package.
- Move libstdc++ documentation to new libstdc++-doc package.
- Remove libstdc++, fortran and objc .la files.
- Adjust dependencies to shared libraries.
* Mon Jul 10 2006 rguenther@suse.de
- No longer revert fix for PR26068.
- Add patch to fix PR28016.
* Wed Jul  5 2006 rguenther@suse.de
- Update to 4.1 SVN head.
* Thu Jun 22 2006 rguenther@suse.de
- Disable hack that made -mno-tls-direct-seg-refs the default
  on x86_64.  [#185782]
- The great spec file rewrite.  Split everything into 32/64bit
  subpackages.
* Tue Jun  6 2006 rguenther@suse.de
- Revert fix for PR26068.
- Annotate icecream crosses as having binary payload.
- Package libffi.
* Tue May 30 2006 rguenther@suse.de
- Update to gcc-4_1-branch head.  Fixes #22743.
- Strip binaries and libs for the icecream backends.
- Split libgfortran shared library into own package.
- Build and package the Objective C++ frontend.
- No longer package fastjar stuff.
- Instead of reverting the fix for PR26757 apply the fix for PR27793.
  [#179518]
* Mon May 29 2006 rguenther@suse.de
- Revert patch for PR26757 which causes MPlayer build failures.
* Thu May 25 2006 rguenther@suse.de
- Update to 4.1.1 release.
* Wed May 17 2006 rguenther@suse.de
- Update to gcc-4_1-branch head.
* Mon May 15 2006 rguenther@suse.de
- Update to gcc-4_1-branch head.
- Depend on mpfr-devel.
* Sat May  6 2006 rguenther@suse.de
- Update to gcc-4_1-branch head and remove rpm patches that are
  now obsoleted.  [#173029 (and more)]
* Wed May  3 2006 matz@suse.de
- Add patch for PR27409, an ICE.  [#170939]
* Wed May  3 2006 rguenther@suse.de
- Add patch for PR27364, VRP miscompiles multiplication with overflow,
  miscompilation of binutils.
- Add patch for PR14261 for ia64, s390 and s390x, ICE for code resembling to
  yacc output.  [#171728]
* Fri Apr 28 2006 rguenther@suse.de
- Add patch for PR26399, -fprofile-generate/use checksum
  mismatches.  [#159466]
* Sat Apr 22 2006 rguenther@suse.de
- Add patch to fix fallout from patch for PR27095, fix PR27260.
* Thu Apr 20 2006 rguenther@suse.de
- Add patch to fix ppc long-double varargs ABI issue.  [#167932]
* Wed Apr 19 2006 rguenther@suse.de
- Add patch to reorder indexed load/store operands on rs6000.  [#161673]
* Tue Apr 18 2006 rguenther@suse.de
- Add patch for PR25917, wrong assembly generated on ia64
  for certain bitops and extensions.
- Add patch for PR26777, std::pubseekoff throwing away buffered
  data on error.
- Add patch for PR26996, SCEV analysis ICEing on vector types.
- Add patch for PR27006, wrong assembly genrated on ppc/ppc64
  for altivec constant loading.
- Add patch for PR27095, memset and strcmp evaluating length argument
  twice.
- Add patch for PR27134, ICEing on (int)floor() and other rounding
  functions with -ffast-math.
- Add patch for PR27162, using == instead of the binary predicate
  specified for std::search_n.
* Sat Apr  8 2006 rguenther@suse.de
- Update patch for PR26919 to also collect garbage.
* Fri Apr  7 2006 rguenther@suse.de
- Add patch for PR26919.
- Merge up to rev 112748 for gfortran changes on the branch.
  [#162890, #163146]
* Mon Apr  3 2006 rguenther@suse.de
- Add patch for PR26763.
* Thu Mar 30 2006 rguenther@suse.de
- Fix #153386 in a different way.
- Add patch for PR26042.  [#148884]
* Mon Mar 27 2006 rguenther@suse.de
- Really fix #153386.
* Thu Mar 23 2006 rguenther@suse.de
- Update patch for PR26565.
- Add patch for PR25737.
- Add patch for OpenOffice problems.  [#153386]
- Add patch for PR26826.  [#160095]
- Enable Cairo support in libjava.
* Wed Mar 15 2006 rguenther@suse.de
- Add patch to update to r112077.
  [#19543, #26489, #26557, #26672, #18859, #26004, #26524, #26587,
  [#26345], #26453, #26291, #25885, #26054, #26041, #26064, #26107,
  [#26393], #20938, #24519, #25395, #25054, #25089, #24557, #23092,
  [#25045], #25075, #21303, #26499, #26554, #21303, #24903, #26136,
  [#26464], #26423, #26532, #26132, #26526, #25713, #24461, #26103]
- Patches for PR26587, PR26526 no longer necessary.
- Update patch for PR26565.
- Add patch for PR26643.
- Move libgcjawt.(so|la) and lib-gnu-java-awt-peer-gtk.(so|la) to the
  gcc-java package because these are dlopened by the runtime. [#157655]
* Tue Mar  7 2006 rguenther@suse.de
- Add patch for PR26587, miscompilation due to wrong PTA info.
- Add patch for PR26565, unaligned accesses on strict alignment targets.
- Add patch for PR26526, missing 64bit export for __copy_streambufs.
* Tue Feb 28 2006 rguenther@suse.de
- Update to 4.1.0 release.
- Patch for PR25603 no longer necessary.
- Add patch for PR24879.
- Add fortran WHERE optimizations.
* Thu Feb 23 2006 rguenther@suse.de
- Update to SVN head.
- Patch for PR26350 no longer necessary.
- Add patch for PR25603.  [#152811]
- Add patch for NVL152859.  [#152859]
* Sat Feb 18 2006 rguenther@suse.de
- Update to SVN head.  [#26334]
- Patch for PR26209 no longer necessary.
- Add patch for PR26350.
* Tue Feb 14 2006 rguenther@suse.de
- Update to SVN head.  [#150421]
- Add patches for latent VRP and fold bugs.
- Enable long-double-128 by default on s390, s390x, ppc and ppc64.
- Add patch for PR26209.
* Sun Feb 12 2006 matz@suse.de
- Don't add /lib/*/libc.so to the cross backends.
* Fri Feb 10 2006 rguenther@suse.de
- Update to SVN head.  [#25251][#26180]
* Wed Feb  8 2006 matz@suse.de
- Make the cross-ppc-icecream-backend accept -m64.
* Tue Feb  7 2006 rguenther@suse.de
- Update to SVN head.
- S390 long double patch now upstream.
- Drop in long double patchset from FC.
- Disable all Ada workarounds.
* Wed Feb  1 2006 rguenther@suse.de
- Update to SVN head.
- Re-diff ada patch for ppc.
- Add another minor libstdc++ improvement from Paolo.
- Re-enable --with-tune=z9-109 --with-arch=z900 change on s390(x).
- Update long double patch for s390.
* Mon Jan 30 2006 rguenther@suse.de
- Update to SVN head.
- Add ppc32, s390(x) 128bit long-double support.
- Add missing intrinsics to emm headers.
- Add candidate patch for ada build problem on s390x.
- Revert --with-tune=z9-109 --with-arch=z900 change on s390(x).
- Patch for PR25324 no longer necessary.
* Fri Jan 27 2006 rguenther@suse.de
- Update to SVN head as of Mon Jan 23.
- Add patches for PR22275, PR25626 and PR25324.
- Patches for PR23948 and PR25535 no longer necessary.
- Exchange patches that fix atomic builtins for a better one.
- Add patch to fix unexpected EOF in fix-header.
- Update patch(es) for generic CPU model.
- Add gfortran matmul patch.
- Use --with-tune=z9-109 --with-arch=z900 for s390(x).
- Disable ada for s390x.
- Don't build fortran for crosses.  Don't depend on gmp either.
- Re-add dejagnu and expect build dependencies if running the testsuite.
- Require gcc-ada build dependency only if building ada.
* Thu Jan 26 2006 sndirsch@suse.de
- no longer use sysroot for cross-avr to fix linker error
  "this linker was not configured to use sysroots" (Bug #145783)
* Thu Jan 26 2006 ro@suse.de
- re-added glibc-devel-32bit to gcc.spec
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 rguenther@suse.de
- Add gmp-devel to build dependencies.
* Thu Jan 12 2006 rguenther@suse.de
- Fix large-model patch.
- Enable large-model, blended CPU model and the multilib searchdir
  patches for STABLE, too.
* Mon Jan  9 2006 rguenther@suse.de
- Update to current SVN head.
- Patches for PR22533 and PR25130 no longer necessary.
* Sun Jan  8 2006 sndirsch@suse.de
- enabled build of g++ for cross-avr; crash-bobby (www.qfix.de)
  needs a C++ compiler
* Fri Jan  6 2006 aj@suse.de
- Update generic model patch.
* Tue Jan  3 2006 rguenther@suse.de
- Update to current SVN head.
- Workaround for PR25023 should be no longer necessary.
- Add patch for PR25130.
- Add patches from RH SRPM, java fixes, ia64 ssp support,
  s390 and ppc64 atomic fixes.
* Fri Dec 30 2005 aj@suse.de
- Do not package static java libraries since linking statically
  with them will not really work.
- Update to current SVN head.
* Thu Dec 22 2005 rguenther@suse.de
- Add patch for generic CPU model (x86_64 only) for BETA.
* Wed Dec 21 2005 rguenther@suse.de
- Enable checking for BETA.
- Enable large-model patch for BETA.
- Enable patch for PR20425 for BETA.
* Wed Dec 21 2005 aj@suse.de
- Update to current SVN head.
* Mon Dec 19 2005 rguenther@suse.de
- Add patch for PR25310.
- Remove libssp again, glibc has the required support now.
- Remove SPARCles from the spec file.
- Downgrade checking to release checking in STABLE.
- Fix all unpackaged symlinks.
* Thu Dec 15 2005 rguenther@suse.de
- Disable patch for PR20425 for stable.
- Fix libssp location for ppc.
* Mon Dec 12 2005 rguenther@suse.de
- Fix 64bit libssp install on ppc.
- Update patch for PR20425.
* Sun Dec 11 2005 aj@suse.de
- Update to current SVN head.
- Enable libssp.
* Fri Dec  9 2005 rguenther@suse.de
- Update to current SVN head.
- C++ strict aliasing warnings now upstream.
- Patch for PR24908 no longer necessary.
- Add patches for PR25180, PR25311 and PR20425.
- Enable Ada workaround for hppa, too.
- Enable --enable-secureplt for ppc and ppc64 targets.
* Wed Nov 30 2005 rguenther@suse.de
- Update to current SVN head.
- Add patches for PR24823 and PR24908.
* Thu Nov 24 2005 rguenther@suse.de
- Add patch for PR24982.
- Add workaround for PR25023.
* Wed Nov 23 2005 rguenther@suse.de
- Update to current SVN head.
- Add different fix for PR22533.
- Disable Ada workarounds for s390 and s390x.
- Add patch for PR24626.
- Patches for PR20928, PR24172 and PR23717 no longer necessary.
- Ada EH on s390 fixed upstream.
- Add patch to disable aliasing-warnings in std::string.
* Fri Nov 18 2005 schwab@suse.de
- Fix Ada library links.
* Wed Nov 16 2005 rguenther@suse.de
- Update to current SVN head.
- Patch for PR22509 no longer necessary.
- No more reversion of AJs patch to libgfortran.
- Disable inst-prefix-dir.patch.
- Re-enable Ada workarounds, fix Ada EH on s390.
* Thu Nov 10 2005 rguenther@suse.de
- Update to current SVN head.
- Check if we accidentially end up with make -j0 and fix it.
- Update patch for PR23948.
- Patches for PR24627 and PR24230 no longer necessary.
- Revert patch from AJ to libgfortran.h.
* Wed Nov  2 2005 rguenther@suse.de
- Update to current SVN head.
- Patches for PR24225, PR24351 no longer necessary.
- Add patches for PR24230, PR24627, PR22509.
- Disable some of the ada workarounds.
- Disable java for arm.
* Tue Nov  1 2005 rguenther@suse.de
- Exchange patch for PR24351.
* Thu Oct 27 2005 rguenther@suse.de
- Add patch for PR24351.
- Use libstdc++ allocator "new" instead of default "mt"
  for compatibility and possibly LSB3.0 conformance.
* Mon Oct 24 2005 rguenther@suse.de
- Update to current CVS head.
- Add patch for PR24225.
* Wed Oct 19 2005 rguenther@suse.de
- Update to current CVS head.
- Disable strict-aliasing patch.
- Patch for PR24255 is no longer needed.
- Fix RPM_OPT_FLAGS for cross-avr to not include
  - march/cpu/tune stuff.
* Fri Oct 14 2005 rguenther@suse.de
- Add patch for PR24172.
- Add patch for PR24255.
* Wed Oct 12 2005 rguenther@suse.de
- Update to current CVS head.
- Add patch for PR23948.
- Update strict-aliasing patch.
- Apply patch6 to ppc/ppc64, too.
* Mon Oct 10 2005 rguenther@suse.de
- Add patch to warn about papering over strict-aliasing bugs.
* Sat Oct  8 2005 aj@suse.de
- Update to current CVS head.
* Sat Oct  1 2005 schwab@suse.de
- Update to current CVS head.
- Add workaround for PR22533.
* Thu Sep 22 2005 schwab@suse.de
- Build Ada with -O0 and reenable.
* Tue Sep 20 2005 aj@suse.de
- Update to current CVS head.
- Add patch for PR22438.
- Disable Ada on ppc, s390, s390x for now.
- Fix .la files.
* Mon Sep 19 2005 aj@suse.de
- Update to current CVS head.
* Fri Sep 16 2005 aj@suse.de
- Update to CVS Head.
* Fri Sep  9 2005 schwab@suse.de
- Update to current CVS.
* Tue Sep  6 2005 schwab@suse.de
- Disable testsuite for now.
* Sun Sep  4 2005 schwab@suse.de
- Avoid strict aliasing warning.
* Sat Sep  3 2005 schwab@suse.de
- Update to CVS HEAD.
* Fri Aug 26 2005 aj@suse.de
- Update to current CVS to fix GCC bug #23546.
* Thu Aug 25 2005 matz@suse.de
- Update to current CVS.
- Enable java on hppa.
* Tue Aug 23 2005 meissner@suse.de
- Applied bugfix for fortify checking from Jakub Jelinek.
  (gcc PR middle-end/23484)
* Thu Aug 18 2005 matz@suse.de
- Update to current CVS.
* Wed Aug 17 2005 matz@suse.de
- Enable Ada on hppa.
* Tue Aug 16 2005 jw@suse.de
- cross-avr-gcc: Enabled avr2 support in micro-cross.spec.in
  fixes #105206
- micro-cross.spec.in more robust against gcc.spec changes.
* Thu Aug 11 2005 aj@suse.de
- Fix PR23326 [#99249 - kopete miscompilation].
- Update to current CVS for:
  * Fix PR23312 [ada ICEs]
  * Fix PR23266 [C++ ICE]
* Thu Aug 11 2005 aj@suse.de
- Update to current CVS.
- Add gcc-locale package again [#103757].
- Fix gcc-mainline 64bit lib names.
* Sun Aug  7 2005 matz@suse.de
- Update to current CVS.
- Fixes PR23192, which results in miscompilation of libpcap [#102460].
- Don't build nof libs on pcc.
* Sat Aug  6 2005 schwab@suse.de
- Also fix cross-avr specfile.
* Fri Aug  5 2005 schwab@suse.de
- Fix cross specfiles.
* Fri Aug  5 2005 matz@suse.de
- Package nof dir on ppc again.
- Put 64bit libs into separate rpms on ppc.
- Rename gnat and gnat-runtime to gcc-ada resp. libada.
* Thu Aug  4 2005 matz@suse.de
- Update to current CVS.
- Made libgcj (and friends) not biarch.
- Added libgcjawt for OpenOffice.
* Wed Jul 27 2005 matz@suse.de
- Update to current CVS.
* Wed Jul 20 2005 matz@suse.de
- Update to current CVS.
* Thu Jul 14 2005 matz@suse.de
- Update to current CVS.
* Wed Jul 13 2005 schwab@suse.de
- Parallel build fix.
- Properly detect ppc64 kernel.
* Fri Jul  1 2005 aj@suse.de
- Update to current CVS.
* Fri Jun 24 2005 matz@suse.de
- Fix partly empty c++config.h also for ppc.
- Fix libstdc++-devel filelist.
* Wed Jun 22 2005 matz@suse.de
- Fix use of wrong macro, leading to partly empty c++config.h.
* Tue Jun 21 2005 matz@suse.de
- Update to current CVS.
- Add fix for PR21721 (ia64 p0 problem).
- Add fix for PR22028.
* Mon Jun 13 2005 matz@suse.de
- Update to current CVS.
- Pull fix for PR21171 from mainline (should fix grub, #84600).
- Add fix for PR21985 (also a grub problem).
* Thu Jun  9 2005 schwab@suse.de
- Update to current CVS.
- Fix broken unwind info in profiling code.
* Fri Jun  3 2005 matz@suse.de
- Update to current CVS.
- Workaround for PR21041.
* Sun May 29 2005 aj@suse.de
- Update to current CVS.
- Package pre_checkin.sh so that Robert can use our package.
* Thu May 26 2005 schwab@suse.de
- Fix fortify patch.
* Thu May 26 2005 aj@suse.de
- Update to current CVS.
* Sun May 22 2005 aj@suse.de
- Update to current CVS.
- Fix visibility hidden problems PR C++/19664 and
  PR middle-end/20218.
* Sat May 21 2005 aj@suse.de
- Update to current CVS.
* Thu May 19 2005 schwab@suse.de
- Update to current CVS, fixes glibc miscompilation.
* Wed May 18 2005 aj@suse.de
- Update to current CVS - should fix ia64
  ICEs.
* Wed May 18 2005 aj@suse.de
- Update to current CVS.
* Mon May 16 2005 aj@suse.de
- Update to current CVS.
- Fix PowerPC gcc-mainline package.
* Sun May 15 2005 aj@suse.de
- Update to current CVS.
- Fix warnings about uninitialized variables.
* Fri May 13 2005 matz@suse.de
- Fix cross-avr-gcc (uses now target=avr, not avr-elf).
* Thu May 12 2005 matz@suse.de
- Add gjnih to gcc-java.
* Thu May 12 2005 matz@suse.de
- Update to current CVS.
- Fix filelists (libgfortran.so and libmudflapth.so).
- Add cross-avr-gcc from jw@suse.de.
* Sat May  7 2005 matz@suse.de
- Add cross-alpha-icecream-backend.
* Wed May  4 2005 matz@suse.de
- Update to current CVS.
* Tue May  3 2005 schwab@suse.de
- Update to current CVS.
* Mon Apr 25 2005 matz@suse.de
- Fix endless loop in postreload on ia64.
* Sun Apr 24 2005 aj@suse.de
- Update to current CVS.
- Fix pre_checkin for gcc-mainline.
* Sat Apr 23 2005 aj@suse.de
- Update to current CVS.
- Fix one PRE bug.
* Sat Apr 23 2005 schwab@suse.de
- Provide/obsolete gcc-locale.
* Fri Apr 22 2005 matz@suse.de
- Fix ulimit call to use kbyte not mbyte.
* Fri Apr 22 2005 matz@suse.de
- Update to current CVS, which is a prerelease of 4.0.1.
* Sat Apr 16 2005 meissner@suse.de
- Added RH fortify extensions.
* Fri Apr 15 2005 matz@suse.de
- Update to current CVS.
- Fix PR20963: ICE compiling dosbox (preliminary patch).
* Wed Apr 13 2005 ro@suse.de
- fix last patch to apply
* Tue Apr 12 2005 schwab@suse.de
- Fix GCC PR20924: Wrong floating point flags for inline division.
* Tue Apr 12 2005 matz@suse.de
- Testpatch for GCC PR20973: miscompile of khtml.
* Mon Apr 11 2005 aj@suse.de
- Fix GCC PR20928: ICE compiling clisp.
- Fix GCC PR20929: ICE compiling mozilla.
* Sun Apr 10 2005 aj@suse.de
- Update to current CVS.
- Fix GCC PR20917: ICE compiling glibc on s390.
- Fix GCC PR20126: Miscompilation of python.
* Sat Apr  9 2005 aj@suse.de
- Update to current CVS.
* Fri Apr  8 2005 schwab@suse.de
- Build cross compiler backends for icecream.
* Fri Apr  8 2005 aj@suse.de
- Update to current CVS.
* Thu Apr  7 2005 aj@suse.de
- Update to current CVS.
* Thu Apr  7 2005 meissner@suse.de
- Add a patch for PR 20739 (ncurses bugfix)
* Wed Apr  6 2005 aj@suse.de
- Update to current CVS.
- Require gettext packages for build.
* Tue Apr  5 2005 aj@suse.de
- Update to current CVS.
* Fri Apr  1 2005 aj@suse.de
- Add fixes for Arm from Ulrich Hecht.
* Fri Apr  1 2005 aj@suse.de
- Update to current CVS.
- Fix GCC PR20635.
* Wed Mar 30 2005 aj@suse.de
- Update to current CVS.
* Mon Mar 28 2005 aj@suse.de
- Update to current CVS.
- build multiarch on PPC.
- Add one fix for GCC PR19345.
* Thu Mar 24 2005 schwab@suse.de
- Update to current CVS.
* Sun Mar 20 2005 aj@suse.de
- Update to current CVS.
* Thu Mar 17 2005 aj@suse.de
- Update to current CVS.
* Sat Mar 12 2005 aj@suse.de
- Update to current CVS.
* Thu Mar 10 2005 aj@suse.de
- Update to current CVS.
* Mon Mar  7 2005 aj@suse.de
- Update to current CVS.
* Fri Mar  4 2005 schwab@suse.de
- Update to current CVS.
* Mon Feb 28 2005 aj@suse.de
- Update to current CVS.
* Sat Feb 26 2005 aj@suse.de
- Update to current CVS.
* Wed Feb 23 2005 aj@suse.de
- Update to current CVS.
* Sun Feb 20 2005 aj@suse.de
- Update to current CVS.
- Fix PR20017.
* Fri Feb 18 2005 aj@suse.de
- Update to current CVS.
* Thu Feb 17 2005 schwab@suse.de
- Add timeout to ACATS test script.
* Thu Feb 17 2005 aj@suse.de
- Update to current CVS.
* Tue Feb 15 2005 schwab@suse.de
- Update to current CVS.
- Apply ada-nonopt.patch also on ppc.
* Mon Feb 14 2005 matz@suse.de
- Don't use icecream, strip senseless warning options from
  RPM_OPT_FLAGS.
* Fri Feb 11 2005 schwab@suse.de
- Update to current CVS.
* Wed Feb  9 2005 aj@suse.de
- Update to current CVS.
* Tue Feb  8 2005 aj@suse.de
- Update to current CVS.
* Thu Feb  3 2005 aj@suse.de
- Update to current CVS.
* Wed Feb  2 2005 aj@suse.de
- Update to current CVS.
* Sun Jan 30 2005 aj@suse.de
- Update to current CVS.
* Fri Jan 28 2005 aj@suse.de
- Update to current CVS.
* Wed Jan 26 2005 aj@suse.de
- Update to current CVS.
* Tue Jan 25 2005 meissner@suse.de
- Added sentinel-c++.diff to avoid faulty sentinel
  warnings due to C++ NULL being __null.
* Mon Jan 24 2005 aj@suse.de
- Update to current CVS.
* Thu Jan 20 2005 aj@suse.de
- Update to current CVS.
* Wed Jan 19 2005 aj@suse.de
- Install C++ headers into /usr/include/c++/<version>.
- Fix c++config.h for multilib systems.
- Remove old obsoletes/provides for gjava, gpp, gccinfo, gobjc,
  minigcc and gnat-3.13p-runtime.
- Update to current CVS.
* Sun Jan 16 2005 aj@suse.de
- Enable ada on s390x.
- Update to current CVS.
* Fri Jan 14 2005 aj@suse.de
- Update to current CVS.
* Wed Jan 12 2005 aj@suse.de
- Update to current CVS.
- Enable ada on s390.
* Tue Jan 11 2005 aj@suse.de
- Update to current CVS.
* Mon Jan 10 2005 aj@suse.de
- Update to current CVS.
- Disable testsuite run for now.
* Sun Jan  9 2005 aj@suse.de
- Update to current CVS.
- Always run testsuite for gcc-mainline.
* Sat Jan  8 2005 aj@suse.de
- Update to current CVS.
* Mon Jan  3 2005 aj@suse.de
- Update to current CVS.
- Remove obsolete patches.
* Sun Jan  2 2005 schwab@suse.de
- Fix names of installed Ada programs.
- Update tree-sra patch.
* Sun Jan  2 2005 aj@suse.de
- Update to current CVS.
* Fri Dec 31 2004 aj@suse.de
- Update to current CVS.
- Fix gcc-mainline build.
* Mon Dec 27 2004 aj@suse.de
- Update to current CVS.
* Thu Dec 23 2004 aj@suse.de
- Update to current CVS.
* Fri Dec 17 2004 aj@suse.de
- Update to current CVS.
* Wed Dec 15 2004 aj@suse.de
- Update to current CVS.
* Tue Dec 14 2004 schwab@suse.de
- Update to current CVS.
* Mon Dec 13 2004 aj@suse.de
- Update to current CVS.
* Fri Dec 10 2004 schwab@suse.de
- Fix requires for mainline build.
* Thu Dec  9 2004 aj@suse.de
- Update to current CVS.
- Fix mainline build.
* Wed Dec  8 2004 aj@suse.de
- Update to current CVS.
* Sat Dec  4 2004 schwab@suse.de
- Update to current CVS.
* Tue Nov 30 2004 aj@suse.de
- Update to current CVS.
* Sun Nov 28 2004 schwab@suse.de
- Update to current CVS.
- Enable Ada on ppc.
* Tue Nov 23 2004 schwab@suse.de
- Add proposed fix for PR17746.
- Work around PR17356.
- Enable Ada on ia64.
* Mon Nov 22 2004 aj@suse.de
- Update to current CVS.
* Thu Nov 18 2004 schwab@suse.de
- Update to current CVS.
* Sun Nov 14 2004 schwab@suse.de
- Update to current CVS.
- Use libunwind on ia64.
* Mon Nov  8 2004 schwab@suse.de
- Update to current CVS.
- Disable broken patch.
* Sat Nov  6 2004 schwab@suse.de
- Update to current CVS.
* Mon Nov  1 2004 schwab@suse.de
- Update to current CVS.
* Wed Oct 27 2004 aj@suse.de
- update to current CVS
- add some bugfixes.
* Mon Oct 25 2004 aj@suse.de
- Enable Ada for x86 and x86-64 architectures.
- Rename gnat to gcc-ada and gnat-runtime to libada.
- Update to current CVS.
* Fri Oct 22 2004 aj@suse.de
- Update to current CVS.
* Mon Oct 18 2004 aj@suse.de
- Update to current CVS.
* Sun Oct 17 2004 aj@suse.de
- Update to current CVS.
* Wed Oct 13 2004 aj@suse.de
- Update to current CVS.
- Fix #17906.
* Tue Oct 12 2004 aj@suse.de
- Update to current CVS.
- Fix pr17520.
* Sun Oct 10 2004 aj@suse.de
- Update to current CVS.
* Fri Oct  8 2004 aj@suse.de
- Update to current CVS.
* Fri Oct  1 2004 aj@suse.de
- Update to current CVS.
- Remove now unneeded patch.
* Wed Sep 29 2004 aj@suse.de
- Update to current CVS.
* Fri Sep 24 2004 aj@suse.de
- Remove obsolete patch for head +1.
* Fri Sep 24 2004 schwab@suse.de
- Update to current CVS.
* Mon Sep 20 2004 aj@suse.de
- Update to current CVS.
* Sat Sep 18 2004 schwab@suse.de
- Remove extra header.
* Sat Sep 18 2004 aj@suse.de
- Update to current CVS.
* Fri Sep 17 2004 aj@suse.de
- Update to current CVS.
* Thu Sep 16 2004 aj@suse.de
- Update to current CVS.
* Wed Sep 15 2004 aj@suse.de
- Update to current CVS.
* Tue Sep 14 2004 aj@suse.de
- Update to current CVS.
- Fix spec file for PPC.
- Add patch to fix some aliasing issues.
* Mon Sep 13 2004 aj@suse.de
- GCC 3.5 is now GCC 4.0.
- Update to current CVS.
- Fix package list.
* Fri Sep 10 2004 aj@suse.de
- Do no pack libgcc_s.so.1 twice.
* Thu Sep  9 2004 aj@suse.de
- Update to current CVS.
- Adjust spec file for changes.
* Thu Sep  2 2004 aj@suse.de
- Fix for powerpc.
- Update to current CVS.
* Fri Aug 27 2004 aj@suse.de
- Use DESTDIR again after setting LD_LIBRARY_PATH.
* Fri Aug 27 2004 aj@suse.de
- Update to current 3.5 CVS.
- Do not use DESTDIR/RPM_BUILD_ROOT since libtool will not
  install java correctly with it.
* Fri Aug 20 2004 aj@suse.de
- Fix RPM_OPT_FLAGS.
- Update to current 3.5 CVS.
* Thu Aug 19 2004 aj@suse.de
- Update to current 3.5 CVS.
* Mon Aug  9 2004 aj@suse.de
- Update to current 3.5 CVS.
* Mon Jul 19 2004 aj@suse.de
- Update to current 3.5 CVS.
- Fix /usr install.
* Wed Jun 16 2004 aj@suse.de
- Update to current 3.5 CVS.
- Install into /usr.
* Thu Jun 10 2004 aj@suse.de
- Fix build on PPC.
- Update to current 3.5 CVS.
* Wed Jun  9 2004 aj@suse.de
- Update to current 3.5 CVS.
* Fri Jun  4 2004 aj@suse.de
- Update to current 3.5 CVS.
- Fix spec file for x86-64 and hppa.
* Thu Jun  3 2004 aj@suse.de
- Fix spec file.
- Update to current 3.5 CVS.
* Wed Jun  2 2004 aj@suse.de
- Update to current 3.5 CVS, rework spec file.
* Thu May 27 2004 aj@suse.de
- Update to GCC 3.5 CVS.
* Wed Apr 28 2004 aj@suse.de
- Update to current CVS.
* Tue Apr 20 2004 aj@suse.de
- Avoid warnings.
- Update to current 3.4 CVS.
* Fri Apr  9 2004 aj@suse.de
- Update to current 3.4 CVS.
* Sat Mar 13 2004 aj@suse.de
- Fix spec file.
- Update to current 3.4 CVS.
* Tue Mar  9 2004 aj@suse.de
- Update to current 3.4 CVS.
* Tue Mar  2 2004 aj@suse.de
- Update to current 3.4 CVS.
* Fri Feb 27 2004 aj@suse.de
- Update to current 3.4 CVS.
* Wed Feb 18 2004 aj@suse.de
- Update to current 3.4 CVS.
* Mon Feb  9 2004 aj@suse.de
- Update to current 3.4 CVS.
* Mon Feb  2 2004 aj@suse.de
- Update to current CVS.
* Mon Jan 26 2004 aj@suse.de
- Update to current CVS.
* Fri Jan 23 2004 aj@suse.de
- Update to current CVS.
* Thu Jan 22 2004 aj@suse.de
- Update to current CVS.
* Mon Jan 19 2004 aj@suse.de
- Update to current CVS.
* Fri Jan 16 2004 aj@suse.de
- Update to current CVS.
* Wed Jan 14 2004 aj@suse.de
- Update to current CVS.
- Fix spec file.
* Tue Jan 13 2004 aj@suse.de
- Fix package list.
* Tue Jan 13 2004 aj@suse.de
- Disable Ada on AMD64.
* Tue Jan 13 2004 aj@suse.de
- Update to current CVS.
* Mon Jan 12 2004 aj@suse.de
- Update to current CVS.
* Wed Jan  7 2004 aj@suse.de
- Update to current CVS.
* Tue Dec 16 2003 aj@suse.de
- Update to current CVS.
- change config-dist.sh to check-build.sh.
- minimal-toc is not needed anymore on ppc64.
- Fix PPC nof file list.
* Wed Dec 10 2003 aj@suse.de
- Update to current CVS.
* Thu Dec  4 2003 aj@suse.de
- Update to current CVS.
- Fix package list.
* Wed Dec  3 2003 aj@suse.de
- Update to current CVS.
* Sun Nov 30 2003 aj@suse.de
- Update to current CVS.
* Fri Nov 28 2003 aj@suse.de
- Update to current CVS.
* Wed Oct 29 2003 aj@suse.de
- Fix package list for i386.
* Wed Oct 29 2003 aj@suse.de
- New package.
